// ETMInterrupt.cpp : Defines the entry point for the console application.
//


#include "stdafx.h"


void __stdcall v_InterruptServiceRoutine(HANDLE h_DeviceHandle,
                                         DWORD  dw_Status,
                                         DWORD  dw_InterruptSource,
                                         DWORD  dw_InterruptMask,
                                         DWORD  dw_ArgsSize,
                                         PDWORD pdw_Args)
{
	static int interruptCounter = 0;
	DWORD module = 0;
	DWORD counter = 0;

	UNREFERENCED_PARAMETER(h_DeviceHandle);
	UNREFERENCED_PARAMETER(dw_Status);
	UNREFERENCED_PARAMETER(dw_ArgsSize);

	dw_InterruptMask >>= 16;

	/* Find the interrupting module */
	for (module = 0; ((dw_InterruptSource >> module) & 1) == 0 && module < 4; module++);
	/* Find the interrupting counter */
	for (counter = 0; ((dw_InterruptMask >> counter) & 1) == 0 && counter < 2; counter++);

	/* Print the ETM status */
	printf("Int #%d - ETM module %d counter %d value: %d total time: %d\n",
			interruptCounter++,
			module,
			counter,
			pdw_Args[0], 
			pdw_Args[1]);
}

int _tmain(int argc, _TCHAR* argv[])
{
	int i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;
	DWORD dw_Temp = 0;
	BYTE b_Module = 0;
	BYTE b_ETMNbr = 0;
	BYTE b_InputClk = 0;
	BYTE b_TimingUnit = 0;
	DWORD dw_Timing = 0;
	DWORD dw_RealTiming = 0;

	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	printf("Read ETM value test sample");
	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	if (i_ReturnValue != 0)
		return -1;

	/* Set the module */
	do
	{
		_flushall();
		printf("\nSelect the module (0 to 3): ");
		scanf_s("%u", &dw_Temp);
	}
	while (dw_Temp > 3);
	b_Module = (BYTE)dw_Temp;
	
	/* Set the counter number */
	do
	{
		_flushall();
		printf("Select the number of the ETM counter (0 to 1): ");
		scanf_s("%u", &dw_Temp);
	}
	while (dw_Temp > 1);
	b_ETMNbr = (BYTE)dw_Temp;

	/* Set the input clock */
	do
	{
		_flushall();
		printf("Select the input clock (PCI 30MHz, PCI 33MHz or onboard 40 MHz): ");
		scanf_s("%u", &dw_Temp);
	}
	while (dw_Temp != 30 && dw_Temp != 33 && dw_Temp != 40);
	b_InputClk = (BYTE)dw_Temp;

	/* Set the timing unit */
	do
	{
		_flushall();
		printf("Select the timing unit (0: ns, 1: us, 2: ms): ");
		scanf_s("%u", &dw_Temp);
	}
	while (dw_Temp > 2);
	b_TimingUnit = (BYTE)dw_Temp;

	/* Set the timing value */
	do
	{
		_flushall();
		printf("Select the timing value: ");
		scanf_s("%u", &dw_Temp);
	}
	while (dw_Temp == 0 || dw_Temp > 559240500);
	dw_Timing = dw_Temp;

	/* Register the interrupt function */
	i_ReturnValue = i_PCI1710_SetBoardIntRoutine(h_BoardHandle, &v_InterruptServiceRoutine);
	if (i_ReturnValue != 0)
	{
		printf("\n i_PCI1710_SetBoardIntRoutine Error : %d", i_ReturnValue);
		_getch();
		return -1;
	}

	/* Initialize the ETM counter */
	i_ReturnValue = i_PCI1710_InitETM(h_BoardHandle,
									  b_Module,
									  b_InputClk,
									  b_TimingUnit,
									  dw_Timing,
									  &dw_RealTiming);
	if (i_ReturnValue != 0)
	{
		printf("\n i_PCI1710_InitETM Error : %d", i_ReturnValue);
		_getch();
		return -1;
	}
	
	/* Enable the ETM counter */
	i_ReturnValue = i_PCI1710_EnableETM(h_BoardHandle,
										b_Module,
										b_ETMNbr,
										1, /* High level time */
										1, /* Rising edge trigger */
										1, /* Continuous mode */
										1, /* Wait until a rising edge */
										1  /* Enable interrupts */
										);
	if (i_ReturnValue != 0)
	{
		printf("\n i_PCI1710_EnableETM Error : %d", i_ReturnValue);
		_getch();
		return -1;
	}

	printf("\n Press ESC to exit\n\n");
	while (_getch() != VK_ESCAPE);

	/* Disable the ETM counter */
	i_ReturnValue = i_PCI1710_DisableETM(h_BoardHandle, b_Module, b_ETMNbr);
	if (i_ReturnValue != 0)
		printf("\n i_PCI1710_DisableETM Error : %d", i_ReturnValue);

	i_ReturnValue = i_PCI1710_CloseBoard(h_BoardHandle);
	printf("\n Press any key to exit the sample ...");
	_getch();

	return 0;
}
