// CounterReadWriteClearWithIndex.cpp: Defines the entry point for the console application.
//

#include "stdafx.h"

void __stdcall v_InterruptRoutine(HANDLE h_DeviceHandle, DWORD, DWORD dw_InterruptSource, DWORD dw_InterruptMask, DWORD dw_ArgsSize, PDWORD)
{
	int i_ReturnValue;
	BYTE b_ModuleNbr = 0;
	DWORD dw_LatchValue;

	/* Skip interruptions not related to the index feature */
	if (dw_ArgsSize == 0 || (dw_InterruptMask & 0x4) == 0)
		return;

	/* Find out which module interrupted */
	for (b_ModuleNbr = 0; ((dw_InterruptSource >> b_ModuleNbr) & 1) == 0; b_ModuleNbr++);

	/* Read the latch value */
	i_ReturnValue = i_PCI1710_ReadLatchRegisterValue(h_DeviceHandle, b_ModuleNbr, 0, &dw_LatchValue);
	if (i_ReturnValue != 0)
		printf("\ni_PCI1710_ReadLatchRegisterValue error: %d\n", i_ReturnValue);
	else
		printf("\nIndex interrupt on module %d! Latched value: %-11lu\n", b_ModuleNbr, dw_LatchValue);
}

int _tmain(int, _TCHAR **)
{
	int i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;
	BYTE b_ModuleNbr = 0;
	BYTE b_CounterRange = 0;
	DWORD dw_FirstCounterValue = 0;
	DWORD dw_SecondCounterValue = 0;
	BYTE b_FirstCounterModus = 0;
	BYTE b_FirstCounterOption = 0;
	BYTE b_SecondCounterModus = 0;
	BYTE b_SecondCounterOption = 0;
	BYTE pb_CounterModeSelection[4] = {128, 15, 3, 0};
	CHAR *pc_CounterModeSelection[4] = {"Direct mode", "Simple mode", "Double mode", "Quadruple mode"};
	DWORD dw_WriteValue = 0;
	DWORD dw_CounterValue = 0;
	BYTE b_CounterSelection = 0;
	int i_Key = 0;
	BYTE b_Cpt = 0;
	DWORD dw_Temp = 0;

	printf("Test counter read write clear sample\n");

	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	printf("\n");

	if (i_ReturnValue == 0)
	{
		/* Get module number to test */
		do
		{
			printf("Select the module you want to use (0 to 3): ");
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 3);
		b_ModuleNbr = (BYTE) dw_Temp;

		/* Get module range */
		do
		{
			printf("Select the module range you want to use (0: 1x32 bits or 1: 2x16bits): ");
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 1);
		b_CounterRange = (BYTE) dw_Temp << 4;

		if (b_CounterRange == PCI1710_16BIT_COUNTER)
		{
			printf("Select the counter mode for the first counter: \n");
			do
			{
				/* Get the counter mode */
				for (b_Cpt = 0; b_Cpt < 4; b_Cpt++)
				{
					printf("%hu. %s\n", b_Cpt, pc_CounterModeSelection[b_Cpt]);
				} 
				printf("Your selection: ");
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 3);
			b_FirstCounterModus = pb_CounterModeSelection[dw_Temp];

			printf("Select the first counter option: \n");

			if (b_FirstCounterModus == PCI1710_DIRECT_MODE)
			{
				do
				{
					printf("Decrement or increment (0: decrement, 1: increment): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_FirstCounterOption = (BYTE)(PCI1710_INCREMENT * dw_Temp);
			}
			else
			{
				do
				{
					printf("Hysteresis off or on (0: off, 1: on): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_FirstCounterOption = (BYTE)(PCI1710_HYSTERESIS_ON * dw_Temp);
			}

			printf("Select the counter mode for the second counter: \n");
			do
			{
				/* Get the counter mode */
				for (b_Cpt = 0; b_Cpt < 4; b_Cpt++)
				{
					printf("%hu. %s\n", b_Cpt, pc_CounterModeSelection[b_Cpt]);
				}
				printf("Your selection: ");
				scanf_s ("%lu", &dw_Temp);
			} while (dw_Temp > 3);
			b_SecondCounterModus = pb_CounterModeSelection[dw_Temp];

			printf("Select the second counter option: \n");

			if (b_SecondCounterModus == PCI1710_DIRECT_MODE)
			{
				do
				{
					printf("Decrement or increment (0: decrement, 1: increment): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_SecondCounterOption = (BYTE)(PCI1710_INCREMENT * dw_Temp);
			}
			else
			{
				do
				{
					printf("Hysteresis off or on (0: off, 1: on): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_SecondCounterOption = (BYTE)(PCI1710_HYSTERESIS_ON * dw_Temp);
			}
		}
		else
		{
			printf("Select the counter mode for the counter: \n");
			do
			{
				/* Get the counter mode */
				for (b_Cpt = 0; b_Cpt < 4; b_Cpt++)
				{
					printf("%hu. %s\n", b_Cpt, pc_CounterModeSelection[b_Cpt]);
				}
				printf("Your selection: ");
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 3);
			b_FirstCounterModus = pb_CounterModeSelection[dw_Temp];

			printf("Select the counter option: \n");

			if (b_FirstCounterModus == PCI1710_DIRECT_MODE)
			{
				do
				{
					printf("Decrement or increment (0: decrement, 1: increment): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_FirstCounterOption = (BYTE)(PCI1710_INCREMENT * dw_Temp);
			}
			else
			{
				do
				{
					printf("Hysteresis off or on (0: off, 1: on): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_FirstCounterOption = (BYTE)(PCI1710_HYSTERESIS_ON * dw_Temp);
			}

			b_SecondCounterModus = 0;
			b_SecondCounterOption = 0;
		}


		/* Initialise the incremental counter */
		i_ReturnValue = i_PCI1710_InitCounter(h_BoardHandle,
		                                      b_ModuleNbr,
		                                      b_CounterRange,
		                                      b_FirstCounterModus,
		                                      b_FirstCounterOption,
		                                      b_SecondCounterModus,
		                                      b_SecondCounterOption);
		if (i_ReturnValue == 0)
		{
			printf("\ni_PCI1710_InitCounter OK\n\n");

			/* Check if index should be enabled or not */
			do
			{
				printf("Index off or on (0: off, 1: on): ");
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 1);
			
			if (dw_Temp > 0)
			{
				BYTE b_ReferenceAction = 0;
				BYTE b_IndexOperation = 0;
				BYTE b_AutoMode = 0;

				/* Get the reference mode */
				do
				{
					printf("Reference off or on (0: off, 1: on): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_ReferenceAction = (BYTE)dw_Temp;

				/* Get the index operation */
				do
				{
					printf("Index operation:\n"
					       "0. Clear on rising edge\n"
					       "1. Latch on rising edge\n"
					       "2. Clear on falling edge\n"
					       "3. Latch on falling edge\n"
					       "4. Latch & clear on rising edge\n"
					       "5. Latch & clear on falling edge\n"
					       "Your selection: ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 5);
				b_IndexOperation = (BYTE)dw_Temp;

				/* Check if index auto mode should be enabled or not */
				do
				{
					printf("Index auto reset mode off or on (0: off, 1: on): ");
					scanf_s("%lu", &dw_Temp);
				} while (dw_Temp > 1);
				b_AutoMode = (BYTE)dw_Temp;

				i_ReturnValue = i_PCI1710_SetBoardIntRoutine(h_BoardHandle, &v_InterruptRoutine);
				if (i_ReturnValue != 0)
					printf("\ni_PCI1710_SetBoardIntRoutine error: %d\n", i_ReturnValue);
				else
				{
					i_ReturnValue = i_PCI1710_InitIndex(h_BoardHandle,
														 b_ModuleNbr,
														 b_ReferenceAction,
														 b_IndexOperation,
														 b_AutoMode,
														 1 /* Enable interrupts */);
					if (i_ReturnValue != 0)
						printf("\ni_PCI1710_InitIndex error: %d\n", i_ReturnValue);
					else
					{
						i_ReturnValue = i_PCI1710_EnableIndex(h_BoardHandle, b_ModuleNbr);
						if (i_ReturnValue != 0)
							printf("\ni_PCI1710_EnableIndex error: %d\n", i_ReturnValue);
					}
				}
			}

			printf("\n****   Press 'W' to write a value in the counter,   ****\n");
			printf("****   'C' to clear its current value and any       ****\n");
			printf("****   other key to stop the sample                 ****\n\n");

			if (b_CounterRange == PCI1710_16BIT_COUNTER)
			{
				for (;;)
				{
					/* Read the first counter */
					i_ReturnValue = i_PCI1710_Read16BitCounterValue(h_BoardHandle,
					                                                b_ModuleNbr,
					                                                0,
					                                                &dw_FirstCounterValue);
					
					if (i_ReturnValue != 0)
						printf("\ni_PCI1710_Read16BitCounterValue for the first counter error: %d\n", i_ReturnValue);

					/* Read the second counter */
					i_ReturnValue = i_PCI1710_Read16BitCounterValue(h_BoardHandle,
					                                                b_ModuleNbr,
					                                                1,
					                                                &dw_SecondCounterValue);

					if (i_ReturnValue != 0)
						printf("\ni_PCI1710_Read16BitCounterValue for the second counter error: %d\n", i_ReturnValue);

					/* Print the values of the two counters */
					printf ("\rModule: %d, first counter value = %-6u, second counter value = %-6u", b_ModuleNbr, dw_FirstCounterValue, dw_SecondCounterValue);

					if (_kbhit())
					{
						i_Key = _getch();
						if ((i_Key == 'C') || (i_Key == 'c'))
						{
							i_ReturnValue = i_PCI1710_ClearCounterValue(h_BoardHandle, b_ModuleNbr);
							if (i_ReturnValue != 0)
								printf("\ni_PCI1710_ClearCounterValue error: %d\n", i_ReturnValue);
						}
						else if ((i_Key == 'W') || (i_Key == 'w'))
						{
							do
							{
								printf("\nOn which counter do you want to write (0: counter 0, 1: counter 1, 2: both counters)? ");
								scanf_s("%lu", &dw_Temp);
							} while (dw_Temp > 2);
							b_CounterSelection = (BYTE)dw_Temp;

							if ((b_CounterSelection == 0) || (b_CounterSelection == 1))
							{
								do
								{
									printf("\nEnter the value to write on the counter %d (0 to 0xFFFF (65535)): ", b_CounterSelection);
									scanf_s("%lu", dw_Temp);
								} while (dw_Temp > 0xFFFF);
								dw_WriteValue = dw_Temp;

								i_ReturnValue = i_PCI1710_Write16BitCounterValue(h_BoardHandle, b_ModuleNbr, b_CounterSelection, dw_WriteValue);
								if (i_ReturnValue != 0)
									printf("\ni_PCI1710_Write16BitCounterValue error: %d", i_ReturnValue);
							}
							else if (b_CounterSelection == 2)
							{
								do
								{
									printf("\nEnter the value to write on the counter 0 (0 to 0xFFFF (65535)): ");
									scanf_s("%lu", dw_Temp);
								} while (dw_Temp > 0xFFFF);
								dw_WriteValue = dw_Temp;

								i_ReturnValue = i_PCI1710_Write16BitCounterValue(h_BoardHandle, b_ModuleNbr, 0, dw_WriteValue);
								if (i_ReturnValue != 0)
									printf("\ni_PCI1710_Write16BitCounterValue error: %d\n", i_ReturnValue);

								do
								{
									printf("\nEnter the value to write on the second counter 1 (0 to 0xFFFF (65535)): ");
									scanf_s("%lu", dw_Temp);
								} while (dw_Temp > 0xFFFF);
								dw_WriteValue = dw_Temp;

								i_ReturnValue = i_PCI1710_Write16BitCounterValue(h_BoardHandle, b_ModuleNbr, 1, dw_WriteValue);
								if (i_ReturnValue != 0)
									printf("\ni_PCI1710_Write16BitCounterValue error: %d\n", i_ReturnValue);
							}
						}
						else
							break;
					}
				}
			}
			else if (b_CounterRange == PCI1710_32BIT_COUNTER)
			{
				for (;;)
				{
					i_ReturnValue = i_PCI1710_LatchCounter(h_BoardHandle, b_ModuleNbr, 1);
					if (i_ReturnValue != 0)
						printf("\ni_PCI1710_LatchCounter error: %d\n", i_ReturnValue);
					i_ReturnValue = i_PCI1710_ReadLatchRegisterValue(h_BoardHandle, b_ModuleNbr, 1, &dw_CounterValue);
					if (i_ReturnValue == 0)
						printf("\rCounter value: %-11lu", dw_CounterValue);
					else
						printf("\ni_PCI1710_ReadLatchRegisterValue error: %d\n", i_ReturnValue);
					
					if (_kbhit())
					{
						i_Key = _getch();
						if ((i_Key == 'C') || (i_Key == 'c'))
						{
							i_ReturnValue = i_PCI1710_ClearCounterValue(h_BoardHandle, b_ModuleNbr);
							if (i_ReturnValue != 0)
								printf("\ni_PCI1710_ClearCounterValue error: %d\n", i_ReturnValue);
						}
						else if ((i_Key == 'W') || (i_Key == 'w'))
						{
							printf("\nValue to write (0 to 0xFFFFFFFF (4294967295)): ");
							scanf_s("%lu", &dw_WriteValue);
							if (dw_WriteValue > 0xFFFFFFFF)
								break;
							else
							{
								i_ReturnValue = i_PCI1710_Write32BitCounterValue(h_BoardHandle, b_ModuleNbr, dw_WriteValue);
								if (i_ReturnValue != 0)
									printf("\ni_PCI1710_Write32BitCounterValue error: %d\n", i_ReturnValue);
							}
						}
						else
							break;
					}
				}
			}
		}
		else
		{
			printf("\ni_PCI1711_InitCounter error: %d\n", i_ReturnValue);
		}

		i_PCI1710_DisableIndex(h_BoardHandle, b_ModuleNbr);
		i_PCI1710_CloseBoard(h_BoardHandle);
	}

	printf("\n\nPress any key to exit the sample ...");
	_getch();

	return 0;
}
