#include "stdafx.h"


/**
* Interrupt routine. This function will be called each time we get an interrupt from the board
**/
void __stdcall v_InterruptServiceRoutine(HANDLE h_DeviceHandle,
                                         DWORD  dw_Status,
                                         DWORD  dw_InterruptSource,
                                         DWORD  dw_InterruptMask,
                                         DWORD  dw_ArgsSize,
                                         PDWORD pdw_Args)
{
	UNREFERENCED_PARAMETER(h_DeviceHandle);
	UNREFERENCED_PARAMETER(dw_Status);
	UNREFERENCED_PARAMETER(dw_ArgsSize);
	UNREFERENCED_PARAMETER(pdw_Args);
	BYTE source = 5;
	BYTE mask = 5;

	/*If interrupts are used, tests if one occured*/
	printf("\nAn interrupt occured!\n");

	/* Gets the index of the module that generated the interrupt */
	if ((dw_InterruptSource & 1) != 0)
		source = 0;
	else if ((dw_InterruptSource & 2) != 0)
		source = 1;
	else if ((dw_InterruptSource & 4) != 0)
		source = 2;
	else if ((dw_InterruptSource & 8) != 0)
		source = 3;
	else
	{
		printf("Interrupt source invalid\n");
		source = 5;
	}

	/* Gets the index of the PWM that generated the interrupt */
	if ((dw_InterruptMask & 0x1) != 0)
		mask = 0;
	else if ((dw_InterruptMask & 0x2) != 0)
		mask = 1;
	else
	{
		printf("Interrupt mask invalid\n");
		mask = 5;
	}

	if ((source != 5) && (mask !=5))
	printf("The source is the PWM %d of the module %d.\n", mask, source);
}


/**
* This function is used to ask the user which low and high timing values he wants
**/
void GetLowHighTiming(BYTE b_Unit, ULONG *ul_Low, ULONG *ul_High)
{
	DWORD dw_Tmp = 0;

	if (b_Unit == 0)
	{
		printf("Select a low timing value (150 to 4294967295): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 150) || (dw_Tmp > 4294967295));
		*ul_Low = (ULONG)dw_Tmp;

		printf("Select a high timing value (150 to 4294967295): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 150) || (dw_Tmp > 4294967295));
		*ul_High = (ULONG)dw_Tmp;
	}
	else if (b_Unit == 1)
	{
		printf("Select a low timing value (1 to 429496729): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 429496729));
		*ul_Low = (ULONG)dw_Tmp;

		printf("Select a high timing value (1 to 429496729): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 429496729));
		*ul_High = (ULONG)dw_Tmp;
	}
	else if (b_Unit == 2)
	{
		printf("Select a low timing value (1 to 429496): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 429496));
		*ul_Low = (ULONG)dw_Tmp;

		printf("Select a high timing value (1 to 429496): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 429496));
		*ul_High = (ULONG)dw_Tmp;
	}
	else if (b_Unit == 3)
	{
		printf("Select a low timing value (1 to 429): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 429));
		*ul_Low = (ULONG)dw_Tmp;

		printf("Select a high timing value (1 to 429): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 429));
		*ul_High = (ULONG)dw_Tmp;
	}
	else if (b_Unit == 4)
	{
		printf("Select a low timing value (1 to 7): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 7));
		*ul_Low = (ULONG)dw_Tmp;

		printf("Select a high timing value (1 to 7): ");
		do
		{
			scanf_s("%lu", &dw_Tmp);
		} while ((dw_Tmp < 1) || (dw_Tmp > 7));
		*ul_High = (ULONG)dw_Tmp;
	}
}


int _tmain(int argc, _TCHAR* argv[])
{
	int i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;

	BYTE b_Module = 0;
	BYTE b_PWMNbr = 0;
	BYTE b_TimingUnit[2] = {1};
	ULONG ul_LowTiming[2] = {1};
	ULONG ul_HighTiming[2] = {1};
	ULONG ul_RealLowTiming[2] = {0};
	ULONG ul_RealHighTiming[2] = {0};
	BYTE b_StartLevel[2] = {0};
	BYTE b_StopMode[2] = {0};
	BYTE b_StopLevel[2] = {0};
	BYTE b_ExternGate[2] = {0};
	BYTE b_InterruptFlag[2] = {0};
	BYTE i = 0;
	DWORD dw_Temp = 0;

	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	printf("**********************************************\n");
	printf("****           EnablePWM sample           ****\n");
	printf("**********************************************\n\n");

	/* Open a board */
	printf("\n\n");
	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		printf("\nError %d in i_Utils_OpenBoard\n\n", i_ReturnValue);
		goto end;
	}

	// Get the number of the module to use
	printf("Select the module (0 to 3): ");
	do
	{
		scanf_s("%lu", &dw_Temp);
	} while(dw_Temp > 3);
	b_Module = (BYTE)dw_Temp;

	// Get the PWM(s) to use
	printf("Select the PWM:\n");
	printf("\t0: PWM 0\n\t1: PWM 1\n\t2: both PWMs\n");
	do
	{
		scanf_s("%lu", &dw_Temp);
	} while(dw_Temp > 2);
	b_PWMNbr = (BYTE)dw_Temp;

	// Case of the use of only one PWM
	if ((b_PWMNbr == 0) || (b_PWMNbr == 1))
	{
		// Get the timing unit to use
		printf("Select a timing unit:\n");
		printf("\t0: ns\n\t1: us\n\t2: ms\n\t3: sec\n\t4: min\n");
		do
		{
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 4);
		b_TimingUnit[b_PWMNbr] = (BYTE)dw_Temp;

		// Get the low and high timing to use
		GetLowHighTiming(b_TimingUnit[b_PWMNbr], &ul_LowTiming[b_PWMNbr], &ul_HighTiming[b_PWMNbr]);

		// Gets the start level to use
		printf("Select a start level:\n");
		printf("\t0: the period will start with a low level\n\t1: the period will start with a high level\n");
		do
		{
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 1);
		b_StartLevel[b_PWMNbr] = (BYTE) dw_Temp;
		printf("\n");

		// Gets the stop mode to use
		printf("Select a stop mode:\n");
		printf("\t0: 0: the PWM will be stopped directly after the call of the i_PCI1710_DisablePWM function\n\t1: the PWM will be stopped after the end of the last period after the call of the disable function\n");
		do
		{
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 1);
		b_StopMode[b_PWMNbr] = (BYTE) dw_Temp;
		printf("\n");

		// Gets the stop level to use
		printf("Select a stop level\n");
		printf("\t0: the output signal will keep its level when the PWM will be disabled\n\t1: it will be stopped at low after the PWM will be disabled\n\t2: it will be stopped at high after the PWM will be disabled\n");
		do
		{
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 2);
		b_StopLevel[b_PWMNbr] = (BYTE) dw_Temp;
		printf("\n");

		// Gets the extern gate enabling to use
		printf("Use of the extern gate signal:\n");
		printf("\t0: no\n\t1: yes\n");
		do
		{
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 2);
		b_ExternGate[b_PWMNbr] = (BYTE) dw_Temp;
		printf("\n");

		// Gets the interrupt flag
		printf("Enable interrupt:\n");
		printf("\t0: no\n\t1: yes (an interrupt will occur after each end of state)\n");
		do
		{
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 1);
		b_InterruptFlag[b_PWMNbr] = (BYTE) dw_Temp;
		printf("\n");
	}

	// Case of the use of the two PWMs
	else if (b_PWMNbr == 2)
	{
		for (i = 0; i < 2; i++)
		{
			printf("\n**********************************************\n");
			printf("****               PWM %d:                ****\n", i);
			printf("**********************************************\n\n");

			// Gets the timing unit to use
			printf("Select a timing unit:\n");
			printf("\t0: ns\n\t1: us\n\t2: ms\n\t3: sec\n\t4: min\n");
			do
			{
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 4);
			b_TimingUnit[i] = (BYTE)dw_Temp;

			// Gets the low and high timing to use
			GetLowHighTiming(b_TimingUnit[i], &ul_LowTiming[i], &ul_HighTiming[i]);

			// Gets the start level to use
			printf("Select a start level:\n");
			printf("\t0: the period will start with a low level\n\t1: the period will start with a high level\n");
			do
			{
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 1);
			b_StartLevel[i] = (BYTE) dw_Temp;

			// Gets the stop mode to use
			printf("Select a stop mode:\n");
			printf("\t0: 0: the PWM will be stopped directly after the call of the i_PCI1710_DisablePWM function\n\t1: the PWM will be stopped after the end of the last period after the call of the disable function\n");
			do
			{
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 1);
			b_StopMode[i] = (BYTE) dw_Temp;

			// Gets the stop level to use
			printf("Select a stop level\n");
			printf("\t0: the output signal will keep its level when the PWM will be disabled\n\t1: it will be stopped at low after the PWM will be disabled\n\t2: it will be stopped at high after the PWM will be disabled\n");
			do
			{
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 2);
			b_StopLevel[i] = (BYTE) dw_Temp;

			// Gets the extern gate enabling to use
			printf("Use of the extern gate signal:\n");
			printf("\t0: no\n\t1: yes\n");
			do
			{
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 1);
			b_ExternGate[i] = (BYTE) dw_Temp;
			printf("\n");

			// Gets the interrupt enabling to use
			printf("Enable interrupt:\n");
			printf("\t0: no\n\t1: yes (an interrupt will occur after each end of state)\n");
			do
			{
				scanf_s("%lu", &dw_Temp);
			} while (dw_Temp > 1);
			b_InterruptFlag[i] = (BYTE) dw_Temp;
		}
	}

	// Initializes the PWM(s)
	if ((b_PWMNbr == 0) || (b_PWMNbr == 1))
	{
		i_ReturnValue = i_PCI1710_InitPWM(h_BoardHandle, b_Module, b_PWMNbr, b_TimingUnit[b_PWMNbr], ul_LowTiming[b_PWMNbr], ul_HighTiming[b_PWMNbr], &ul_RealLowTiming[b_PWMNbr], &ul_RealHighTiming[b_PWMNbr]);
		if (i_ReturnValue != 0)
		{
			printf("\nError %d in i_PCI1710_InitPWM %d\n\n", i_ReturnValue, b_PWMNbr);
			goto end;
		}
		else
			printf("\ni_PCI1710_InitPWM %d OK\n\n", b_PWMNbr);

		printf("\nThe low timing value which will be really used for the PWM %d is %lu\n", b_PWMNbr, ul_RealLowTiming[b_PWMNbr]);
		printf("The high timing value which will be really used for the PWM %d is %lu\n\n", b_PWMNbr, ul_RealHighTiming[b_PWMNbr]);
	}
	else if (b_PWMNbr == 2)
	{
		for (i = 0; i < 2; i++)
		{
			i_ReturnValue = i_PCI1710_InitPWM(h_BoardHandle, b_Module, i, b_TimingUnit[i], ul_LowTiming[i], ul_HighTiming[i], &ul_RealLowTiming[i], &ul_RealHighTiming[i]);
			if (i_ReturnValue != 0)
			{
				printf("\nError %d in i_PCI1710_InitPWM %d\n\n", i_ReturnValue, i);
				goto cleanup;
			}
			else
				printf("\ni_PCI1710_InitPWM %d OK\n\n", i);

			printf("\nThe low timing value which will be really used for the PWM %d is %lu\n", i, ul_RealLowTiming[i]);
			printf("The high timing value which will be really used for the PWM %d is %lu\n\n", i, ul_RealHighTiming[i]);
		}
	}

	// Install the interrupt routine if interrupts are enabled
	if ((b_InterruptFlag[0] == 1) || (b_InterruptFlag[1] == 1))
	{
		i_ReturnValue = i_PCI1710_SetBoardIntRoutine(h_BoardHandle, &v_InterruptServiceRoutine);
		if (i_ReturnValue != 0)
		{
			printf("\nError %d in i_PCI1710_SetBoardIntRoutine\n\n", i_ReturnValue);
			goto end;
		}
		else
			printf("\ni_PCI1710_SetBoardIntRoutine OK\n\n");
	}

	// Enables the PWM(s)
	if ((b_PWMNbr == 0) || (b_PWMNbr == 1))
	{
		i_ReturnValue = i_PCI1710_EnablePWM(h_BoardHandle, b_Module, b_PWMNbr, b_StartLevel[b_PWMNbr], b_StopMode[b_PWMNbr], b_StopLevel[b_PWMNbr], b_ExternGate[b_PWMNbr], b_InterruptFlag[b_PWMNbr]);
		if (i_ReturnValue != 0)
		{
			printf("\nError %d in i_PCI1710_EnablePWM %d\n\n", i_ReturnValue, b_PWMNbr);
			goto cleanup;
		}
		else
			printf("\ni_PCI1710_EnablePWM %d OK\n\n", b_PWMNbr);
	}
	else if (b_PWMNbr == 2)
	{
		for (i = 0; i < 2; i++)
		{
			i_ReturnValue = i_PCI1710_EnablePWM(h_BoardHandle, b_Module, i, b_StartLevel[i], b_StopMode[i], b_StopLevel[i], b_ExternGate[i], b_InterruptFlag[i]);
			if (i_ReturnValue != 0)
			{
				printf("\nError %d in i_PCI1710_EnablePWM %d\n\n", i_ReturnValue, i);
				goto cleanup;
			}
			else
				printf("\ni_PCI1710_EnablePWM %d OK\n\n", i);
		}
	}


	printf("\n******************************************\n");
	printf("****    Press ESC to stop the sample    ****\n");
	printf("********************************************\n\n");

	if ((b_InterruptFlag[0] == 1) || (b_InterruptFlag[1] == 1))
		printf("Generating PWM(s).\nWaiting for an interrupt.\n");
	else
		printf("Generating a PWM.\n");

	for(;;)
	{
		if (_kbhit())
		{
			if (_getch() == 27) // Test if ESC
				break;
		}
	}


cleanup:
	if ((b_PWMNbr == 0) || (b_PWMNbr == 1))
	{
		i_ReturnValue = i_PCI1710_DisablePWM(h_BoardHandle, b_Module, b_PWMNbr);
		if (i_ReturnValue != 0)
			printf("\nError %d in i_PCI1710_DisablePWM\n\n", i_ReturnValue);
		else
			printf("\ni_PCI1710_DisablePWM OK\n\n");
	}
	else if (b_PWMNbr == 2)
	{
		for (i = 0; i < 2; i++)
		{
			i_ReturnValue = i_PCI1710_DisablePWM(h_BoardHandle, b_Module, i);
			if (i_ReturnValue != 0)
				printf("\nError %d in i_PCI1710_DisablePWM %d\n\n", i_ReturnValue, i);
			else
				printf("\ni_PCI1710_DisablePWM %d OK\n\n", i);
		}
	}

	// Unistalls the interrupt routine if interrupts are enabled
	if ((b_InterruptFlag[0] == 1) || (b_InterruptFlag[1] == 1))
	{
		i_ReturnValue = i_PCI1710_ResetBoardIntRoutine(h_BoardHandle);
		if (i_ReturnValue != 0)
			printf("\nError %d in i_PCI1710_ResetBoardIntRoutine\n\n", i_ReturnValue);
		else
			printf("\ni_PCI1710_ResetBoardIntRoutine OK\n\n");
	}

end:
	i_ReturnValue = i_PCI1710_CloseBoard(h_BoardHandle);
    if (i_ReturnValue != 0)
		printf("\nError %d in i_PCI1710_CloseBoard\n\n", i_ReturnValue);
    else
		printf("\ni_PCI1710_CloseBoard OK\n\n");

    printf("Press any key to exit the sample...\n");
    _getch();

    return 0;
}
