//##protect##"FileHeader"
/** @file DllImport.cs
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 18.02.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  PCI1710.dll imports 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;

namespace PCI1710_NET
{
    /// <summary>
    /// Contains the prototypes of the DLL functions
    /// </summary>
    public class DllImport
    {
        /// <summary>
        /// Definition of the user interruption function prototype
        /// </summary>
        [UnmanagedFunctionPointer(CallingConvention.StdCall)]
        // /!\ /!\ /!\ This prototype is not standard, do not regenerate automatically!
        public delegate void InterruptFunctionEventHandler(IntPtr handle, UInt32 status, UInt32 source, UInt32 mask, UInt32 argsSize, IntPtr args);

#region "Generic"
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetNumberOfBoards(out Byte pb_NbrOfBoards);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetBoardInformation(Byte b_BoardIndex, UInt32 dw_IdentifierStringSize, out Byte[] pc_Identifier, out UInt32 pdw_UINumber, out UInt32 pdw_DeviceNumber, out UInt32 pdw_BusNumber, out UInt32 pdw_BaseAddress0, out UInt32 pdw_BaseAddress1, out UInt32 pdw_BaseAddress2, out UInt32 pdw_BaseAddress3, out Byte pb_Interrupt);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_OpenBoardViaIndex(Byte b_BoardIndex, out IntPtr ph_DeviceHandle);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_OpenBoardViaIdentifier(out Byte[] pc_Identifier, out IntPtr ph_DeviceHandle);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_CloseBoard(IntPtr h_DeviceHandle);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetDLLVersion(out Int32 pdw_Version);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetDeviceDriverVersion(IntPtr h_DeviceHandle, out Int32 pdw_Version);
		[DllImport("PCI1710.dll")]
		public static extern IntPtr pc_PCI1710_GetLastError(IntPtr h_DeviceHandle);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetBoardIntRoutine(IntPtr h_DeviceHandle, [MarshalAs(UnmanagedType.FunctionPtr)] InterruptFunctionEventHandler interruptFunction);
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ResetBoardIntRoutine(IntPtr h_DeviceHandle);
#endregion

#region "PCI1710"

#endregion
#region "AdditionalFunctions"

		[DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_ConfigureAllModule(IntPtr deviceHandle, byte[] fileName0, byte[] fileName1, byte[] fileName2, byte[] fileName3, out UInt32 writeAddressError);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetBoardHardwareType(IntPtr deviceHandle, out Byte hardwareType);

        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_GetModuleConfiguration(IntPtr h_DeviceHandle, Byte uc_ModuleNbr, out UInt32 pdw_ModuleConfiguration);
		
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EepromAMCCWrite(IntPtr h_DeviceHandle, UInt32 dw_Offset, UInt32 dw_EepromValue);
		
		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EepromAMCCRead(IntPtr h_DeviceHandle, UInt32 dw_Offset, out UInt32 dw_Value);

#endregion
#region "IncrementalCounter"

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitCounter(IntPtr deviceHandle, Byte moduleNumber, Byte counterRange, Byte firstCounterModus, Byte firstCounterOption, Byte secondCounterModus, Byte secondCounterOption);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_CounterAutoTest(IntPtr deviceHandle, out Byte testStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ClearCounterValue(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ClearAllCounterValue(IntPtr deviceHandle);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetInputFilter(IntPtr deviceHandle, Byte moduleNumber, Byte PCIInputClock, Byte filter);

        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_SetInputFilterEFG(IntPtr deviceHandle, Byte moduleNumber, Byte filter);

        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_ConfigDigitalChlUse(IntPtr deviceHandle, Byte moduleNumber, Byte sourceSelect);

        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_InitModuloCompareLogic(IntPtr deviceHandle, Byte moduleNumber, UInt32 compareValue, Byte compareHysteresis);
       
        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_ReadCompareLatchRegister(IntPtr deviceHandle, Byte moduleNumber, out UInt32 latchValue);		

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_LatchCounter(IntPtr deviceHandle, Byte moduleNumber, Byte latchReg);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadLatchRegisterStatus(IntPtr deviceHandle, Byte moduleNumber, Byte latchReg, out Byte latchStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadLatchRegisterValue(IntPtr deviceHandle, Byte moduleNumber, Byte latchReg, out UInt32 latchValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EnableLatchInterrupt(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_DisableLatchInterrupt(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_Read16BitCounterValue(IntPtr deviceHandle, Byte moduleNumber, Byte selectedCounter, out UInt32 counterValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_Read32BitCounterValue(IntPtr deviceHandle, Byte moduleNumber, out UInt32 counterValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_Write16BitCounterValue(IntPtr deviceHandle, Byte moduleNumber, Byte selectedCounter, UInt32 writeValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_Write32BitCounterValue(IntPtr deviceHandle, Byte moduleNumber, UInt32 writeValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitIndex(IntPtr deviceHandle, Byte moduleNumber, Byte referenceAction, Byte indexOperation, Byte autoMode, Byte interruptEnable);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EnableIndex(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_DisableIndex(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetIndexStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte indexStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetIndexAndReferenceSource(IntPtr deviceHandle, Byte moduleNumber, Byte sourceSelection);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitReference(IntPtr deviceHandle, Byte moduleNumber, Byte referenceLevel);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetReferenceStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte referenceStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetUASStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte UASStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetCBStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte CBStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_Get16BitCBStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte CBStatusCounter0, out Byte CBStatusCounter1);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetUDStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte UDStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetInterruptUDLatchedStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte UDStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitExternalStrobe(IntPtr deviceHandle, Byte moduleNumber, Byte externalStrobe, Byte externalStrobeLevel);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitCompareLogic(IntPtr deviceHandle, Byte moduleNumber, UInt32 compareValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EnableCompareLogic(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_DisableCompareLogic(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetDigitalChlOn(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetDigitalChlOff(IntPtr deviceHandle, Byte moduleNumber);

#endregion
#region "PulseEncoder"

        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_InitPulseEncoder(IntPtr deviceHandle, Byte moduleNumber, Byte pulseEncoderNumber, Byte inputLevelSelection, Byte triggerOutputAction, UInt32 startValue);
        
        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_EnablePulseEncoder(IntPtr deviceHandle, Byte moduleNumber, Byte pulseEncoderNumber, Byte cycleSelection, Byte interruptHandling);
        
        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_DisablePulseEncoder(IntPtr deviceHandle, Byte moduleNumber, Byte pulseEncoderNumber);
        
        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_ReadPulseEncoderStatus(IntPtr deviceHandle, Byte moduleNumber, Byte pulseEncoderNumber, out Byte status);
        
        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_ReadPulseEncoderValue(IntPtr deviceHandle, Byte moduleNumber, Byte pulseEncoderNumber, out UInt32 readValue);
        
        [DllImport("PCI1710.dll")]
        public static extern short i_PCI1710_WritePulseEncoderValue(IntPtr deviceHandle, Byte moduleNumber, Byte pulseEncoderNumber, UInt32 writeValue);
#endregion
#region "Timer82C54"

        [DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitTimer(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber, Byte timerMode, UInt32 reloadValue, Byte inputClockSelection, Byte inputClockLevel, Byte outputLevel, Byte hardwareGateLevel);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EnableTimer(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber, Byte interruptEnable);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_DisableTimer(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadTimerValue(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber, out UInt32 timerValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadAllTimerValue(IntPtr deviceHandle, Byte moduleNumber, UInt32 [] timerValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetTimerOutputLevel(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber, out Byte outputLevel);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetTimerProgressStatus(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber, out Byte timerStatus);
        
        [DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetTimerProgressStatusEx(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber, out Byte timerStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_WriteTimerValue(IntPtr deviceHandle, Byte moduleNumber, Byte timerNumber, UInt32 value);

#endregion
#region "DigitalIO"

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadDigitalInputs(IntPtr deviceHandle, Byte moduleNumber, out Byte digitalInputs);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetDigitalOutputsOn(IntPtr deviceHandle, Byte moduleNumber, Byte digitalOutputs);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetDigitalOutputsOff(IntPtr deviceHandle, Byte moduleNumber, Byte digitalOutputs);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetPortConfiguration(IntPtr deviceHandle, Byte moduleNumber, Byte portAMode, Byte portBMode);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetDigitalOutputMemory(IntPtr deviceHandle, Byte memoryFlag);

#endregion
#region "TTL"

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitTTLIODirection(IntPtr deviceHandle, Byte moduleNumber, Byte portAMode, Byte portBMode, Byte portCMode, Byte portDMode);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadTTLIOChannelValue(IntPtr deviceHandle, Byte moduleNumber, Byte portNbr, Byte channelNbr, out Byte value);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadTTLIOPortValue(IntPtr deviceHandle, Byte moduleNumber, Byte portNbr, out Byte value);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadTTLIOAllPortValue(IntPtr deviceHandle, Byte moduleNumber, out UInt32 value);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetTTLIOChlOn(IntPtr deviceHandle, Byte moduleNumber, Byte channelNbr);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetTTLIOChlOff(IntPtr deviceHandle, Byte moduleNumber, Byte channelNbr);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetTTLIOChannelOn(IntPtr deviceHandle, Byte moduleNumber, Byte portNbr, Byte channelNbr);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetTTLIOChannelOff(IntPtr deviceHandle, Byte moduleNumber, Byte portNbr, Byte channelNbr);

#endregion
#region "SSI"

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitSSI(IntPtr deviceHandle, Byte moduleNumber, Byte profileLength, Byte positionLength, Byte turnCptLength, Byte PCIInputClock, UInt32 outputClock, Byte countingMode);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitSSIRawData(IntPtr deviceHandle, Byte moduleNumber, Byte profileLength, Byte PCIInputClock, UInt32 outputClock);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_Read1SSIValue(IntPtr deviceHandle, Byte moduleNumber, Byte SSINbr, out UInt32 position, out UInt32 turn);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_Read1SSIRawDataValue(IntPtr deviceHandle, Byte moduleNumber, Byte SSINbr, out UInt32 valueArray, Byte arraySize);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadAllSSIValue(IntPtr deviceHandle, Byte moduleNumber, UInt32 [] position, UInt32 [] turn);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadAllSSIRawDataValue(IntPtr deviceHandle, Byte moduleNumber, out UInt32 valueArray, Byte arraySize);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadSSI1DigitalInput(IntPtr deviceHandle, Byte moduleNumber, Byte channel, out Byte value);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadSSIAllDigitalInput(IntPtr deviceHandle, Byte moduleNumber, out Byte value);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetSSIDigitalOutputOn(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetSSIDigitalOutputOff(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_StartSSIAcquisition(IntPtr deviceHandle, Byte moduleNumber);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetSSIAcquisitionStatus(IntPtr deviceHandle, Byte moduleNumber, out Byte status);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetSSIValue(IntPtr deviceHandle, Byte moduleNumber, Byte SSINumber, out UInt32 position, out UInt32 turn);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetSSIRawDataValue(IntPtr deviceHandle, Byte moduleNumber, Byte SSINumber, out UInt32 valueArray, Byte arraySize);

#endregion
#region "ETM"

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitETM(IntPtr deviceHandle, Byte moduleNumber, Byte clockSelection, Byte timingUnit, UInt32 timing, out UInt32 realTiming);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EnableETM(IntPtr deviceHandle, Byte moduleNumber, Byte ETM, Byte edgeLevel, Byte triggerLevel, Byte cycleMode, Byte firstTriggerMode, Byte interruptEnable);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_DisableETM(IntPtr deviceHandle, Byte moduleNumber, Byte ETM);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetETMInitialisation(IntPtr deviceHandle, Byte moduleNumber, Byte ETM, out Byte timingUnit, out UInt32 timing, out Byte edgeLevel, out Byte triggerLevel, out Byte cycleMode, out Byte firstTriggerMode, out Byte interruptEnable, out Byte enable);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetETMProgressStatus(IntPtr deviceHandle, Byte moduleNumber, Byte ETM, out Byte ETMStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadETMValue(IntPtr deviceHandle, Byte moduleNumber, Byte ETM, UInt32 timeOut, out Byte ETMStatus, out UInt32 ETMValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadETMTotalTime(IntPtr deviceHandle, Byte moduleNumber, Byte ETM, UInt32 timeOut, out Byte ETMStatus, out UInt32 ETMValue);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadETMDutyCycleValue(IntPtr deviceHandle, Byte moduleNumber, Byte ETM, UInt32 timeOut, out Byte ETMStatus, out Double dutyCycle);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ConvertETMValue(IntPtr deviceHandle, Byte moduleNumber, UInt32 ETMValue, out UInt32 hour, out Byte minute, out Byte second, out UInt32 millisecond, out UInt32 microsecond, out UInt32 nanosecond);

#endregion
#region "PWM"

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_InitPWM(IntPtr deviceHandle, Byte moduleNumber, Byte PWM, Byte timingUnit, UInt32 lowTiming, UInt32 highTiming, out UInt32 realLowTiming, out UInt32 realHighTiming);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetNewPWMTiming(IntPtr deviceHandle, Byte moduleNumber, Byte PWM, Byte timingUnit, UInt32 lowTiming, UInt32 highTiming);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EnablePWM(IntPtr deviceHandle, Byte moduleNumber, Byte PWM, Byte startLevel, Byte stopMode, Byte stopLevel, Byte externGate, Byte interruptEnable);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_DisablePWM(IntPtr deviceHandle, Byte moduleNumber, Byte PWM);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetPWMInitialisation(IntPtr deviceHandle, Byte moduleNumber, Byte PWM, out Byte timingUnit, out UInt32 lowTiming, out UInt32 highTiming, out Byte startLevel, out Byte stopMode, out Byte stopLevel, out Byte externGate, out Byte interruptEnable, out Byte enable);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_GetPWMStatus(IntPtr deviceHandle, Byte modulNbr, Byte PWM, out Byte PWMOutputStatus, out Byte externGateStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadPWM1DigitalInput(IntPtr deviceHandle, Byte modulNbr, Byte inputChannel, out Byte channelStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_ReadPWMAllDigitalInputs(IntPtr deviceHandle, Byte modulNbr, out Byte inputStatus);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_EnableDisablePWMDigitalOutputManualSetting(IntPtr deviceHandle, Byte modulNbr, Byte flag);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetPWMDigitalOutputOn(IntPtr deviceHandle, Byte modulNbr);

		[DllImport("PCI1710.dll")]
		public static extern short i_PCI1710_SetPWMDigitalOutputOff(IntPtr deviceHandle, Byte modulNbr);

#endregion
#region "Misc"
//##protect##"DllImportMisc"
//##protect##"DllImportMisc"
#endregion
    }
}
