using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;

namespace CounterCompareLogicInterrupt
{
    public partial class Filter : Form
    {
        private PCI1710_NET.PCI1710 board;

        public Filter()
        {
            InitializeComponent();
        }

        private void clockCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            filterSelectionCombo.Items.Clear();
          
            filterSelectionCombo.Items.Add("filter not used");
            filterSelectionCombo.Items.Add("100 ns");
            filterSelectionCombo.Items.Add("150 ns");
            filterSelectionCombo.Items.Add("200 ns");
            filterSelectionCombo.Items.Add("250 ns");
            filterSelectionCombo.Items.Add("300 ns");
            filterSelectionCombo.Items.Add("350 ns");
            filterSelectionCombo.Items.Add("400 ns");
            filterSelectionCombo.Items.Add("450 ns");
            filterSelectionCombo.Items.Add("500 ns");
            filterSelectionCombo.Items.Add("550 ns");
            filterSelectionCombo.Items.Add("600 ns");
            filterSelectionCombo.Items.Add("650 ns");
            filterSelectionCombo.Items.Add("700 ns");
            filterSelectionCombo.Items.Add("750 ns");
            filterSelectionCombo.Items.Add("800 ns");
        }

        private void filterButton_Click(object sender, EventArgs e)
        {
            int ret = 0;

            if (modNumCombo.Text == "" || clockCombo.Text == "" || filterSelectionCombo.Text == "")
            {
                MessageBox.Show("Please fill all configuration fields");
                return;
            }

            // First, open a board if needed
            if (this.board == null)
            {
                try
                {
                    this.board = PCI1710_NET.PCI1710.OpenBoard(0);
                    if (this.board == null)
                        throw new Exception();
                }
                catch (Exception)
                {
                    MessageBox.Show("Unable to open the board!\nPlease make sure that the board is plugged in and the driver is correctly installed.", "OpenBoard error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }

            // Initialize the compare logic
            ret = this.board.SetInputFilter(Convert.ToByte(modNumCombo.Text), Convert.ToByte(clockCombo.Text), Convert.ToByte(filterSelectionCombo.SelectedIndex));
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in SetInputFilter!", "SetInputFilter error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }
            MessageBox.Show("Filter set successfully!");

        }

        private void filterEFGButton_Click(object sender, EventArgs e)
        {
            int ret = 0;

            if (modNumCombo.Text == "" || clockCombo.Text == "" || filterSelectionCombo.Text == "")
            {
                MessageBox.Show("Please fill all configuration fields");
                return;
            }

            if (clockCombo.Text != "40")
            {
                MessageBox.Show("Only 40MHz clock is available for filterEFG");
                return;
            }

            // First, open a board if needed
            if (this.board == null)
            {
                try
                {
                    this.board = PCI1710_NET.PCI1710.OpenBoard(0);
                    if (this.board == null)
                        throw new Exception();
                }
                catch (Exception)
                {
                    MessageBox.Show("Unable to open the board!\nPlease make sure that the board is plugged in and the driver is correctly installed.", "OpenBoard error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }

            // Initialize the compare logic
            ret = this.board.SetInputFilterEFG(Convert.ToByte(modNumCombo.Text), Convert.ToByte(filterSelectionCombo.SelectedIndex));
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in SetInputFilterEFG!", "SetInputFilter error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }
            MessageBox.Show("FilterEFG set successfully!");
        }

    }
}
