using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;

namespace CounterCompareLogicInterrupt
{
    public partial class CounterCompareLogicModuloInterrupt : Form
    {
        private PCI1710_NET.PCI1710 board;
        int interruptCounter;
        int cValueAtIntPoint;

        public CounterCompareLogicModuloInterrupt()
        {
            InitializeComponent();
        }

        private void CounterCompareLogicInterrupt_Load(object sender, EventArgs e)
        {
            // Initialize the combo box default values
            modNumCombo.Text = modNumCombo.Items[0].ToString();
            modRangeCombo.Text = modRangeCombo.Items[0].ToString();
            cnt1ModeCombo.Text = cnt1ModeCombo.Items[1].ToString();
            cnt1ModeCombo_SelectedIndexChanged(null, null);
            cnt2ModeCombo.Text = cnt2ModeCombo.Items[1].ToString();
            cnt2ModeCombo_SelectedIndexChanged(null, null);
        }

        private void CounterCompareLogicInterrupt_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (this.board != null)
            {
                stopButton_Click(null, null);
                this.board.ResetBoardIntRoutine();
            }
        }

        private void modRangeCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Show the second counter parameters only if the selected mode is 2x 16bit
            if (modRangeCombo.Text == modRangeCombo.Items[0].ToString())
            {
                cnt2ModeCombo.Visible = cnt2ModeLabel.Visible = cnt2OptionCombo.Visible = cnt2OptionLabel.Visible = cnt2ValueLabel.Visible = cnt2ValueLabel2.Visible = false;
                compareUpDn.Maximum = 4294967295;
            }
            else
            {
                cnt2ModeCombo.Visible = cnt2ModeLabel.Visible = cnt2OptionCombo.Visible = cnt2OptionLabel.Visible = cnt2ValueLabel.Visible = cnt2ValueLabel2.Visible = true;
                compareUpDn.Maximum = 65535;
            }
        }

        // Show the options corresponding to the selected counter mode
        private void cnt1ModeCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[0].ToString())
            {
                cnt1OptionCombo.Items.Clear();
                cnt1OptionCombo.Items.Add("Decrement");
                cnt1OptionCombo.Items.Add("Increment");
                cnt1OptionCombo.Text = cnt1OptionCombo.Items[1].ToString();
            }
            else
            {
                cnt1OptionCombo.Items.Clear();
                cnt1OptionCombo.Items.Add("Hysteresis off");
                cnt1OptionCombo.Items.Add("Hysteresis on");
                cnt1OptionCombo.Text = cnt1OptionCombo.Items[0].ToString();
            }
        }
        private void cnt2ModeCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[0].ToString())
            {
                cnt2OptionCombo.Items.Clear();
                cnt2OptionCombo.Items.Add("Decrement");
                cnt2OptionCombo.Items.Add("Increment");
                cnt2OptionCombo.Text = cnt2OptionCombo.Items[1].ToString();
            }
            else
            {
                cnt2OptionCombo.Items.Clear();
                cnt2OptionCombo.Items.Add("Hysteresis off");
                cnt2OptionCombo.Items.Add("Hysteresis on");
                cnt2OptionCombo.Text = cnt2OptionCombo.Items[0].ToString();
            }
        }

        void interruptEventReceived(object source, PCI1710_NET.InterruptEventArgs args)
        {
            // Increment the interrupt counter
            this.interruptCounter++;
            cValueAtIntPoint = (int)args.args[0];
        }

        private void readTimer_Tick(object sender, EventArgs e)
        {
            int ret;

            // Update the counter information
            Byte moduleNbr = Convert.ToByte(modNumCombo.Text);
            UInt32 cntValue;
            if (modRangeCombo.Text == modRangeCombo.Items[0].ToString())
            {
                ret = this.board.Read32BitCounterValue(moduleNbr, out cntValue);
                if (ret != 0)
                {
                    MessageBox.Show("Error " + ret + " in Read32BitCounterValue!", "Read32BitCounterValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                    return;
                }
                cnt1ValueLabel2.Text = cntValue.ToString();
            }
            else
            {
                ret = this.board.Read16BitCounterValue(moduleNbr, 0, out cntValue);
                if (ret != 0)
                {
                    MessageBox.Show("Error " + ret + " in Read16BitCounterValue!", "Read16BitCounterValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                    return;
                }
                cnt1ValueLabel2.Text = cntValue.ToString();
                ret = this.board.Read16BitCounterValue(moduleNbr, 1, out cntValue);
                if (ret != 0)
                {
                    MessageBox.Show("Error " + ret + " in Read16BitCounterValue!", "Read16BitCounterValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                    return;
                }
                cnt2ValueLabel2.Text = cntValue.ToString();
            }
            interruptCntLabel2.Text = this.interruptCounter.ToString();
            counterValIntPoint.Text = this.cValueAtIntPoint.ToString();
        }

        private void startButton_Click(object sender, EventArgs e)
        {
            int ret = 0;

            // First, open a board if needed
            if (this.board == null)
            {
                try
                {
                    this.board = PCI1710_NET.PCI1710.OpenBoard(0);
                    if (this.board == null)
                        throw new Exception();
                }
                catch (Exception)
                {
                    MessageBox.Show("Unable to open the board!\nPlease make sure that the board is plugged in and the driver is correctly installed.", "OpenBoard error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                // Enable interruptions
                ret = this.board.SetBoardIntRoutine();
                if (ret != 0)
                {
                    MessageBox.Show("Error " + ret + " in SetBoardIntRoutine!", "SetBoardIntRoutine error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                    return;
                }
                this.board.InterruptEventReceived += new PCI1710_NET.PCI1710.InterruptEventHandler(interruptEventReceived);
            }

            // Reset the display
            this.interruptCounter = 0;
            this.cValueAtIntPoint = 0;
            cnt1ValueLabel2.Text = cnt2ValueLabel2.Text = interruptCntLabel2.Text = "---";
            
            // Get the initialization variables
            Byte moduleNbr = Convert.ToByte(modNumCombo.Text);
            Byte cnt1Mode, cnt1Option, cnt2Mode, cnt2Option;

            if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[0].ToString())
                cnt1Mode = 0x80; // Direct mode
            else if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[1].ToString())
                cnt1Mode = 0x0F; // Simple mode
            else if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[2].ToString())
                cnt1Mode = 0x03; // Double mode
            else
                cnt1Mode = 0x00; // Quadruple mode

            if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[0].ToString())
                cnt2Mode = 0x80; // Direct mode
            else if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[1].ToString())
                cnt2Mode = 0x0F; // Simple mode
            else if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[2].ToString())
                cnt2Mode = 0x03; // Double mode
            else
                cnt2Mode = 0x00; // Quadruple mode

            if (cnt1OptionCombo.Text == cnt1OptionCombo.Items[1].ToString())
                cnt1Option = 0x60; // Increment or hysteresis on
            else
                cnt1Option = 0x00; // Decrement or hysteresis off

            if (cnt2OptionCombo.Text == cnt2OptionCombo.Items[1].ToString())
                cnt2Option = 0x60; // Increment or hysteresis on
            else
                cnt2Option = 0x00; // Decrement or hysteresis off

            // Initialize the counters
            ret = this.board.InitCounter(moduleNbr,
                                         (Byte)(modRangeCombo.Text == modRangeCombo.Items[0].ToString() ? 0 : 16),
                                         cnt1Mode,
                                         cnt1Option,
                                         cnt2Mode,
                                         cnt2Option);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in InitCounter!", "InitCounter error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }

            // Initialize the compare logic -- modulo 
            ret = this.board.InitModuloCompareLogic(moduleNbr, Convert.ToUInt32(compareUpDn.Value), Convert.ToByte(compareHysteresis.Value));
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in InitModuloCompareLogic!", "InitModuloCompareLogic error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }


            // Set the digital output mode
            ret = this.board.ConfigDigitalChlUse(moduleNbr, (byte)(digChlCheckbox.Checked ? 1 : 0));
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in ConfigDigitalChlUse!", "ConfigDigitalChlUse error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }


            //Enable the compare logic            
            ret = this.board.EnableCompareLogic(moduleNbr);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in EnableCompareLogic!", "EnableCompareLogic error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }

            // Disable the user interface while the sample runs
            modNumCombo.Enabled = modRangeCombo.Enabled = false;
            cnt1ModeCombo.Enabled = cnt1OptionCombo.Enabled = false;
            cnt2ModeCombo.Enabled = cnt2OptionCombo.Enabled = false;
            compareUpDn.Enabled = false;
            startButton.Enabled = false;
            clearInterrupts.Enabled = false;
            stopButton.Enabled = clearButton.Enabled = true;

            readTimer.Start();
        }

        private void stopButton_Click(object sender, EventArgs e)
        {
            // Disable compare logic and the counter read timer
            int ret = this.board.DisableCompareLogic(Convert.ToByte(modNumCombo.Text));
            if (ret != 0)
                MessageBox.Show("Error " + ret + " in DisableCompareLogic!", "DisableCompareLogic error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            readTimer.Stop();

            // Enable the user interface again
            modNumCombo.Enabled = modRangeCombo.Enabled = true;
            cnt1ModeCombo.Enabled = cnt1OptionCombo.Enabled = true;
            cnt2ModeCombo.Enabled = cnt2OptionCombo.Enabled = true;
            compareUpDn.Enabled = true;
            startButton.Enabled = true;
            clearInterrupts.Enabled = true;
            stopButton.Enabled = clearButton.Enabled = false;
        }

        private void clearButton_Click(object sender, EventArgs e)
        {
            int ret = this.board.ClearCounterValue(Convert.ToByte(modNumCombo.Text));
            if (ret != 0)
                MessageBox.Show("Error " + ret + " in ClearCounterValue!", "ClearCounterValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        private void clearInterrupts_Click(object sender, EventArgs e)
        {
            interruptCntLabel2.Text = "0";
            counterValIntPoint.Text = "0";
        }
    }
}
