using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;

namespace CounterLatchInterrupt
{
    public partial class CounterLatchInterrupt : Form
    {
        private PCI1710_NET.PCI1710 board;
        int strobeACounter, strobeBCounter;

        public CounterLatchInterrupt()
        {
            InitializeComponent();
        }

        private void CounterLatchInterrupt_Load(object sender, EventArgs e)
        {
            // Initialize the combo box default values
            modNumCombo.Text = modNumCombo.Items[0].ToString();
            modRangeCombo.Text = modRangeCombo.Items[0].ToString();
            cnt1ModeCombo.Text = cnt1ModeCombo.Items[1].ToString();
            cnt1ModeCombo_SelectedIndexChanged(null, null);
            cnt2ModeCombo.Text = cnt2ModeCombo.Items[1].ToString();
            cnt2ModeCombo_SelectedIndexChanged(null, null);
            strobeACombo.Text = strobeACombo.Items[1].ToString();
            strobeBCombo.Text = strobeBCombo.Items[1].ToString();
        }

        private void CounterLatchInterrupt_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (this.board != null)
            {
                stopButton_Click(null, null);
                this.board.ResetBoardIntRoutine();
            }
        }

        private void modRangeCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Show the second counter parameters only if the selected mode is 2x 16bit
            if (modRangeCombo.Text == modRangeCombo.Items[0].ToString())
            {
                cnt2ModeCombo.Visible = cnt2ModeLabel.Visible = cnt2OptionCombo.Visible = cnt2OptionLabel.Visible = false;
            }
            else
            {
                cnt2ModeCombo.Visible = cnt2ModeLabel.Visible = cnt2OptionCombo.Visible = cnt2OptionLabel.Visible = true;
            }
        }

        // Show the options corresponding to the selected counter mode
        private void cnt1ModeCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[0].ToString())
            {
                cnt1OptionCombo.Items.Clear();
                cnt1OptionCombo.Items.Add("Decrement");
                cnt1OptionCombo.Items.Add("Increment");
                cnt1OptionCombo.Text = cnt1OptionCombo.Items[1].ToString();
            }
            else
            {
                cnt1OptionCombo.Items.Clear();
                cnt1OptionCombo.Items.Add("Hysteresis off");
                cnt1OptionCombo.Items.Add("Hysteresis on");
                cnt1OptionCombo.Text = cnt1OptionCombo.Items[0].ToString();
            }
        }
        private void cnt2ModeCombo_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[0].ToString())
            {
                cnt2OptionCombo.Items.Clear();
                cnt2OptionCombo.Items.Add("Decrement");
                cnt2OptionCombo.Items.Add("Increment");
                cnt2OptionCombo.Text = cnt2OptionCombo.Items[1].ToString();
            }
            else
            {
                cnt2OptionCombo.Items.Clear();
                cnt2OptionCombo.Items.Add("Hysteresis off");
                cnt2OptionCombo.Items.Add("Hysteresis on");
                cnt2OptionCombo.Text = cnt2OptionCombo.Items[0].ToString();
            }
        }

        void interruptEventReceived(object source, PCI1710_NET.InterruptEventArgs args)
        {
            try
            {
                // Increment the interrupt counters and read the latch value
                if ((args.interruptMask & 1) != 0)
                    this.strobeACounter++;
                if ((args.interruptMask & 2) != 0)
                    this.strobeBCounter++;
                interruptACntLabel2.Text = this.strobeACounter.ToString();
                interruptBCntLabel2.Text = this.strobeBCounter.ToString();
                valueLabel2.Text = args.args[0].ToString();
            }
            catch (Exception){}
        }

        private void startButton_Click(object sender, EventArgs e)
        {
            int ret = 0;

            // First, open a board if needed
            if (this.board == null)
            {
                try
                {
                    this.board = PCI1710_NET.PCI1710.OpenBoard(0);
                    if (this.board == null)
                        throw new Exception();
                }
                catch (Exception)
                {
                    MessageBox.Show("Unable to open the board!\nPlease make sure that the board is plugged in and the driver is correctly installed.", "OpenBoard error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                // Enable interruptions
                ret = this.board.SetBoardIntRoutine();
                if (ret != 0)
                {
                    MessageBox.Show("Error " + ret + " in SetBoardIntRoutine!", "SetBoardIntRoutine error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                    return;
                }
                this.board.InterruptEventReceived += new PCI1710_NET.PCI1710.InterruptEventHandler(interruptEventReceived);
            }

            // Reset the display
            this.strobeACounter = this.strobeBCounter = 0;
            interruptACntLabel2.Text = interruptBCntLabel2.Text = "0";
            valueLabel2.Text = "---";
            
            // Get the initialization variables
            Byte moduleNbr = Convert.ToByte(modNumCombo.Text);
            Byte cnt1Mode, cnt1Option, cnt2Mode, cnt2Option;

            if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[0].ToString())
                cnt1Mode = 0x80; // Direct mode
            else if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[1].ToString())
                cnt1Mode = 0x0F; // Simple mode
            else if (cnt1ModeCombo.Text == cnt1ModeCombo.Items[2].ToString())
                cnt1Mode = 0x03; // Double mode
            else
                cnt1Mode = 0x00; // Quadruple mode

            if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[0].ToString())
                cnt2Mode = 0x80; // Direct mode
            else if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[1].ToString())
                cnt2Mode = 0x0F; // Simple mode
            else if (cnt2ModeCombo.Text == cnt2ModeCombo.Items[2].ToString())
                cnt2Mode = 0x03; // Double mode
            else
                cnt2Mode = 0x00; // Quadruple mode

            if (cnt1OptionCombo.Text == cnt1OptionCombo.Items[1].ToString())
                cnt1Option = 0x60; // Increment or hysteresis on
            else
                cnt1Option = 0x00; // Decrement or hysteresis off

            if (cnt2OptionCombo.Text == cnt2OptionCombo.Items[1].ToString())
                cnt2Option = 0x60; // Increment or hysteresis on
            else
                cnt2Option = 0x00; // Decrement or hysteresis off

            // Initialize the counters
            ret = this.board.InitCounter(moduleNbr,
                                         (Byte)(modRangeCombo.Text == modRangeCombo.Items[0].ToString() ? 0 : 16),
                                         cnt1Mode,
                                         cnt1Option,
                                         cnt2Mode,
                                         cnt2Option);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in InitCounter!", "InitCounter error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }

            // Initialize the latches
            ret = this.board.InitExternalStrobe(moduleNbr, 0, (Byte)(strobeACombo.Text == strobeACombo.Items[0].ToString() ? 0 : 1));
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in InitExternalStrobe!", "InitExternalStrobe error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }
            ret = this.board.InitExternalStrobe(moduleNbr, 1, (Byte)(strobeBCombo.Text == strobeBCombo.Items[0].ToString() ? 0 : 1));
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in InitExternalStrobe!", "InitExternalStrobe error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }
            ret = this.board.EnableLatchInterrupt(moduleNbr);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in EnableLatchInterrupt!", "EnableLatchInterrupt error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }

            // Disable the user interface while the sample runs
            modNumCombo.Enabled = modRangeCombo.Enabled = false;
            cnt1ModeCombo.Enabled = cnt1OptionCombo.Enabled = false;
            cnt2ModeCombo.Enabled = cnt2OptionCombo.Enabled = false;
            strobeACombo.Enabled = strobeBCombo.Enabled = false;
            startButton.Enabled = false;
            stopButton.Enabled = true;
        }

        private void stopButton_Click(object sender, EventArgs e)
        {
            // Disable compare logic and the counter read timer
            int ret = this.board.DisableLatchInterrupt(Convert.ToByte(modNumCombo.Text));
            if (ret != 0)
                MessageBox.Show("Error " + ret + " in DisableLatchInterrupt!", "DisableLatchInterrupt error", MessageBoxButtons.OK, MessageBoxIcon.Error);

            // Enable the user interface again
            modNumCombo.Enabled = modRangeCombo.Enabled = true;
            cnt1ModeCombo.Enabled = cnt1OptionCombo.Enabled = true;
            cnt2ModeCombo.Enabled = cnt2OptionCombo.Enabled = true;
            strobeACombo.Enabled = strobeBCombo.Enabled = true;
            startButton.Enabled = true;
            stopButton.Enabled = false;
        }

        private void clearButton_Click(object sender, EventArgs e)
        {
            int ret = this.board.ClearCounterValue(Convert.ToByte(modNumCombo.Text));
            if (ret != 0)
                MessageBox.Show("Error " + ret + " in ClearCounterValue!", "ClearCounterValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
}
