using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace EnablePWM
{
    public partial class EnablePWM : Form
    {
        /// <summary>
        /// Handle to the first board
        /// </summary>
        PCI1710_NET.PCI1710 board;
        Byte module;
        int interruptPWM0;
        int interruptPWM1;
        int boardIntRoutine;

        /// <summary>
        /// Constructor of the form
        /// </summary>
        public EnablePWM()
        {
            InitializeComponent();
            module = 0;
        }

        /// <summary>
        /// Call at the first load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void EnablePWM_Load(object sender, EventArgs e)
        {
            interruptPWM0 = 0;
            interruptPWM1 = 0;
            boardIntRoutine = 0;

            // Open the first board of the system
            this.board = PCI1710_NET.PCI1710.OpenBoard(0);
            // Error handling
            if (this.board == null)
            {
                MessageBox.Show("Error OpenBoard returned null");
                this.Close();
                return;
            }

            module0Selection.Checked = true;
            stopButton.Enabled = false;

            // Initializes the combo box default values
            timingUnit0Selection.Text = timingUnit0Selection.Items[2].ToString();
            timingUnit1Selection.Text = timingUnit1Selection.Items[2].ToString();
            startLevel0Selection.Text = startLevel0Selection.Items[0].ToString();
            startLevel1Selection.Text = startLevel1Selection.Items[0].ToString();
            stopMode0Selection.Text = stopMode0Selection.Items[0].ToString();
            stopMode1Selection.Text = stopMode1Selection.Items[0].ToString();
            stopLevel0Selection.Text = stopLevel0Selection.Items[0].ToString();
            stopLevel1Selection.Text = stopLevel1Selection.Items[0].ToString();
            externGate0Selection.Text = externGate0Selection.Items[0].ToString();
            externGate1Selection.Text = externGate1Selection.Items[0].ToString();
            interrupt0Selection.Text = interrupt0Selection.Items[0].ToString();
            interrupt1Selection.Text = interrupt1Selection.Items[0].ToString();

            // Registers the interrupt function
            this.board.InterruptEventReceived += new PCI1710_NET.PCI1710.InterruptEventHandler(interruptEventReceived);
        }

        /// <summary>
        /// Occurs when the user closes the form
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void EnablePWM_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (stopButton.Enabled == true)
            {
                stopButton_Click(null, null);
            }
        }

        void interruptEventReceived(object source, PCI1710_NET.InterruptEventArgs args)
        {
            if ((args.interruptMask & 1) != 0)
            {
                // Increment the PWM 0 interrupt counter
                interruptPWM0++;
            }
            if ((args.interruptMask & 2) != 0)
            {
                // Increment the PWM 1 interrupt counter
                interruptPWM1++;
            }
        }

        private void readTimer_Tick(object sender, EventArgs e)
        {
            int returnValue = 0;
            Byte[] timingU = new Byte [2];
            UInt32[] lowT = new UInt32 [2];
            UInt32[] highT = new UInt32 [2];
            Byte[] startL = new Byte[2];
            Byte[] stopM = new Byte[2];
            Byte[] stopL = new Byte[2];
            Byte[] externG = new Byte[2];
            Byte[] interruptF = new Byte[2];
            Byte[] PWME = new Byte[2];
            Byte[] outputS = new Byte[2];
            Byte[] externS = new Byte[2];
            Byte i = 0;

            for (i = 0; i < 2; i++)
            {
                // We read the values of the initialisation parameters
                if ((returnValue = this.board.GetPWMInitialisation(module, i, out timingU[(int)i], out lowT[(int)i], out highT[(int)i], out startL[(int)i], out stopM[(int)i], out stopL[(int)i], out externG[(int)i], out interruptF[(int)i], out PWME[(int)i])) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in GetPWMInitialisation");
                    this.Close();
                    return;
                }

                // Updates the displayed values
                if (timingU[0] == 0)
                    timingUnit0Status.Text = "0 (ns)";
                else if (timingU[0] == 1)
                    timingUnit0Status.Text = "1 (us)";
                else if (timingU[0] == 2)
                    timingUnit0Status.Text = "2 (ms)";
                else if (timingU[0] == 3)
                    timingUnit0Status.Text = "3 (sec)";
                else if (timingU[0] == 4)
                    timingUnit0Status.Text = "4 (min)";

                if (timingU[1] == 0)
                    timingUnit1Status.Text = "0 (ns)";
                else if (timingU[1] == 1)
                    timingUnit1Status.Text = "1 (us)";
                else if (timingU[1] == 2)
                    timingUnit1Status.Text = "2 (ms)";
                else if (timingU[1] == 3)
                    timingUnit1Status.Text = "3 (sec)";
                else if (timingU[1] == 4)
                    timingUnit1Status.Text = "4 (min)";

                lowTiming0Status.Text = lowT[0].ToString();
                lowTiming1Status.Text = lowT[1].ToString();

                highTiming0Status.Text = highT[0].ToString();
                highTiming1Status.Text = highT[1].ToString();

                if (startL[0] == 0)
                    startLevel0Status.Text = "0 (Starts with a low level)";
                else if (startL[0] == 1)
                    startLevel0Status.Text = "1 (Starts with a high level)";
                
                if (startL[1] == 0)
                    startLevel1Status.Text = "0 (Starts with a low level)";
                else if (startL[1] == 1)
                    startLevel1Status.Text = "1 (Starts with a high level)";

                if (stopM[0] == 0)
                    stopMode0Status.Text = "0 (Stops directly after being disabled)";
                else if (stopM[0] == 1)
                    stopMode0Status.Text = "1 (Finishes its period before being disabled)";

                if (stopM[1] == 0)
                    stopMode1Status.Text = "0 (Stops directly after being disabled)";
                else if (stopM[1] == 1)
                    stopMode1Status.Text = "1 (Finishes its period before being disabled)";

                if (stopL[0] == 0)
                    stopLevel0Status.Text = "0 (Keeps its level after being disabled)";
                else if (stopL[0] == 1)
                    stopLevel0Status.Text = "1 (Set to low after being disabled)";
                else if (stopL[0] == 2)
                    stopLevel0Status.Text = "2 (Set to high after being disabled)";

                if (stopL[1] == 0)
                    stopLevel1Status.Text = "0 (Keeps its level after being disabled)";
                else if (stopL[1] == 1)
                    stopLevel1Status.Text = "1 (Set to low after being disabled)";
                else if (stopL[1] == 2)
                    stopLevel1Status.Text = "2 (Set to high after being disabled)";

                if (externG[0] == 0)
                    externGateEnable0Status.Text = "0 (Not used)";
                else if (externG[0] == 1)
                    externGateEnable0Status.Text = "1 (Used)";

                if (externG[1] == 0)
                    externGateEnable1Status.Text = "0 (Not used)";
                else if (externG[1] == 1)
                    externGateEnable1Status.Text = "1 (Used)";

                if (interruptF[0] == 0)
                    interrupt0Status.Text = "0 (Not used)";
                else if (interruptF[0] == 1)
                    interrupt0Status.Text = "1 (Used)";

                if (interruptF[1] == 0)
                    interrupt1Status.Text = "0 (Not used)";
                else if (interruptF[1] == 1)
                    interrupt1Status.Text = "1 (Used)";

                if (PWME[0] == 0)
                    PWMEnable0Status.Text = "0 (Not enabled)";
                else if (PWME[0] == 1)
                    PWMEnable0Status.Text = "1 (Enabled)";

                if (PWME[1] == 0)
                    PWMEnable1Status.Text = "0 (Not enabled)";
                else if (PWME[1] == 1)
                    PWMEnable1Status.Text = "1 (Enabled)";

                // We read the status of the PWM output and of the extern gate
                if ((returnValue = this.board.GetPWMStatus(module, i, out outputS[(int)i], out externS[(int)i])) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in GetPWMStatus");
                    this.Close();
                    return;
                }

                // Updates the displayed values
                output0Status.Text = outputS[0].ToString();
                output1Status.Text = outputS[1].ToString();
                externGate0Status.Text = externS[0].ToString();
                externGate1Status.Text = externS[1].ToString();

                interruptCount0.Text = interruptPWM0.ToString();
                interruptCount1.Text = interruptPWM1.ToString();
            }
        }

        private void timingUnit0Selection_SelectedIndexChanged(object sender, EventArgs e)
        {
            if ((Byte)timingUnit0Selection.SelectedIndex == 0)
            {
                lowTiming0Selection.Minimum = 200;
                highTiming0Selection.Minimum = 200;
                lowTiming0Selection.Maximum = 4294967295;
                highTiming0Selection.Maximum = 4294967295;
                lowTiming0Selection.Value = 200;
                highTiming0Selection.Value = 200;
                lowTimingMinMax0.Text = "From 200 to 4294967295";
                highTimingMinMax0.Text = "From 200 to 4294967295";
            }
            else if ((Byte)timingUnit0Selection.SelectedIndex == 1)
            {
                lowTiming0Selection.Minimum = 1;
                highTiming0Selection.Minimum = 1;
                lowTiming0Selection.Maximum = 429496729;
                highTiming0Selection.Maximum = 429496729;
                lowTiming0Selection.Value = 1;
                highTiming0Selection.Value = 1;
                lowTimingMinMax0.Text = "From 1 to 429496729";
                highTimingMinMax0.Text = "From 1 to 429496729";
            }
            else if ((Byte)timingUnit0Selection.SelectedIndex == 2)
            {
                lowTiming0Selection.Minimum = 1;
                highTiming0Selection.Minimum = 1;
                lowTiming0Selection.Maximum = 429496;
                highTiming0Selection.Maximum = 429496;
                lowTiming0Selection.Value = 1;
                highTiming0Selection.Value = 1;
                lowTimingMinMax0.Text = "From 1 to 429496";
                highTimingMinMax0.Text = "From 1 to 429496";
            }
            else if ((Byte)timingUnit0Selection.SelectedIndex == 3)
            {
                lowTiming0Selection.Minimum = 1;
                highTiming0Selection.Minimum = 1;
                lowTiming0Selection.Maximum = 429;
                highTiming0Selection.Maximum = 429;
                lowTiming0Selection.Value = 1;
                highTiming0Selection.Value = 1;
                lowTimingMinMax0.Text = "From 1 to 429";
                highTimingMinMax0.Text = "From 1 to 429";
            }
            else if ((Byte)timingUnit0Selection.SelectedIndex == 4)
            {
                lowTiming0Selection.Minimum = 1;
                highTiming0Selection.Minimum = 1;
                lowTiming0Selection.Maximum = 7;
                highTiming0Selection.Maximum = 7;
                lowTiming0Selection.Value = 1;
                highTiming0Selection.Value = 1;
                lowTimingMinMax0.Text = "From 1 to 7";
                highTimingMinMax0.Text = "From 1 to 7";
            }
        }

        private void timingUnit1Selection_SelectedIndexChanged(object sender, EventArgs e)
        {
            if ((Byte)timingUnit1Selection.SelectedIndex == 0)
            {
                lowTiming1Selection.Minimum = 200;
                highTiming1Selection.Minimum = 200;
                lowTiming1Selection.Maximum = 4294967295;
                highTiming1Selection.Maximum = 4294967295;
                lowTiming1Selection.Value = 200;
                highTiming1Selection.Value = 200;
                lowTimingMinMax1.Text = "From 200 to 4294967295";
                highTimingMinMax1.Text = "From 200 to 4294967295";
            }
            else if ((Byte)timingUnit1Selection.SelectedIndex == 1)
            {
                lowTiming1Selection.Minimum = 1;
                highTiming1Selection.Minimum = 1;
                lowTiming1Selection.Maximum = 429496729;
                highTiming1Selection.Maximum = 429496729;
                lowTiming1Selection.Value = 1;
                highTiming1Selection.Value = 1;
                lowTimingMinMax1.Text = "From 1 to 429496729";
                highTimingMinMax1.Text = "From 1 to 429496729";
            }
            else if ((Byte)timingUnit1Selection.SelectedIndex == 2)
            {
                lowTiming1Selection.Minimum = 1;
                highTiming1Selection.Minimum = 1;
                lowTiming1Selection.Maximum = 429496;
                highTiming1Selection.Maximum = 429496;
                lowTiming1Selection.Value = 1;
                highTiming1Selection.Value = 1;
                lowTimingMinMax1.Text = "From 1 to 429496";
                highTimingMinMax1.Text = "From 1 to 429496";
            }
            else if ((Byte)timingUnit1Selection.SelectedIndex == 3)
            {
                lowTiming1Selection.Minimum = 1;
                highTiming1Selection.Minimum = 1;
                lowTiming1Selection.Maximum = 429;
                highTiming1Selection.Maximum = 429;
                lowTiming1Selection.Value = 1;
                highTiming1Selection.Value = 1;
                lowTimingMinMax1.Text = "From 1 to 429";
                highTimingMinMax1.Text = "From 1 to 429";
            }
            else if ((Byte)timingUnit1Selection.SelectedIndex == 4)
            {
                lowTiming1Selection.Minimum = 1;
                highTiming1Selection.Minimum = 1;
                lowTiming1Selection.Maximum = 7;
                highTiming1Selection.Maximum = 7;
                lowTiming1Selection.Value = 1;
                highTiming1Selection.Value = 1;
                lowTimingMinMax1.Text = "From 1 to 7";
                highTimingMinMax1.Text = "From 1 to 7";
            }
        }

        private void startButton_Click(object sender, EventArgs e)
        {
            int returnValue = 0;
            Byte i = 0;
            UInt32[] realLTiming = new UInt32 [2];
            UInt32[] realHTiming = new UInt32 [2];
            Byte[] timingUnit = new Byte [2];
            UInt32[] lowTiming = new UInt32 [2];
            UInt32[] highTiming = new UInt32[2];
            Byte[] startLevel = new Byte[2];
            Byte[] stopMode = new Byte[2];
            Byte[] stopLevel = new Byte[2];
            Byte[] interrupt = new Byte[2];
            Byte[] externGate = new Byte[2];

            timingUnit[0] = (Byte)timingUnit0Selection.SelectedIndex;
            timingUnit[1] = (Byte)timingUnit1Selection.SelectedIndex;
            lowTiming[0] = (UInt32)lowTiming0Selection.Value;
            lowTiming[1] = (UInt32)lowTiming1Selection.Value;
            highTiming[0] = (UInt32)highTiming0Selection.Value;
            highTiming[1] = (UInt32)highTiming1Selection.Value;
            startLevel[0] = (Byte)startLevel0Selection.SelectedIndex;
            startLevel[1] = (Byte)startLevel1Selection.SelectedIndex;
            stopMode[0] = (Byte)stopMode0Selection.SelectedIndex;
            stopMode[1] = (Byte)stopMode1Selection.SelectedIndex;
            stopLevel[0] = (Byte)stopLevel0Selection.SelectedIndex;
            stopLevel[1] = (Byte)stopLevel1Selection.SelectedIndex;
            externGate[0] = (Byte)externGate0Selection.SelectedIndex;
            externGate[1] = (Byte)externGate1Selection.SelectedIndex;
            interrupt[0] = (Byte)interrupt0Selection.SelectedIndex;
            interrupt[1] = (Byte)interrupt1Selection.SelectedIndex;

            interruptCount0.Text = "0";
            interruptCount1.Text = "0";
            interruptPWM0 = 0;
            interruptPWM1 = 0;

            if ((((int)interrupt0Selection.SelectedIndex == 1) || ((int)interrupt1Selection.SelectedIndex == 1)) && (boardIntRoutine == 0))
            {
                // Enables the interruptions
                returnValue = this.board.SetBoardIntRoutine();
                if (returnValue != 0)
                {
                    MessageBox.Show("Error " + returnValue + " in SetBoardIntRoutine!", "SetBoardIntRoutine error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                    return;
                }
                boardIntRoutine = 1;
            }
            for (i = 0; i < 2; i++)
            {
                //Call of the init function
                if ((returnValue = this.board.InitPWM(module, i, timingUnit[i], lowTiming[i], highTiming[i], out realLTiming[i], out realHTiming[i])) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in InitPWM");
                    this.Close();
                    return;
                }

                // Call of the enable function
                if ((returnValue = this.board.EnablePWM(module, i, startLevel[i], stopMode[i], stopLevel[i], externGate[i], interrupt[i])) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in EnablePWM");
                    this.Close();
                    return;
                }
            }
            realLow0.Text = realLTiming[0].ToString();
            realLow1.Text = realLTiming[1].ToString();
            realHigh0.Text = realHTiming[0].ToString();
            realHigh1.Text = realHTiming[1].ToString();

            stopButton.Enabled = true;
            startButton.Enabled = false;
            module0Selection.Enabled = false;
            module1Selection.Enabled = false;
            module2Selection.Enabled = false;
            module3Selection.Enabled = false;
            PWM0Label0.Enabled = false;
            PWM1Label0.Enabled = false;
            timingUnit0Selection.Enabled = false;
            timingUnit1Selection.Enabled = false;
            lowTiming0Selection.Enabled = false;
            lowTiming1Selection.Enabled = false;
            realLow0.Enabled = false;
            realLow1.Enabled = false;
            lowTimingMinMax0.Enabled = false;
            lowTimingMinMax1.Enabled = false;
            highTiming0Selection.Enabled = false;
            highTiming1Selection.Enabled = false;
            realHigh0.Enabled = false;
            realHigh1.Enabled = false;
            highTimingMinMax0.Enabled = false;
            highTimingMinMax1.Enabled = false;
            startLevel0Selection.Enabled = false;
            startLevel1Selection.Enabled = false;
            stopMode0Selection.Enabled = false;
            stopMode1Selection.Enabled = false;
            stopLevel0Selection.Enabled = false;
            stopLevel1Selection.Enabled = false;
            externGate0Selection.Enabled = false;
            externGate1Selection.Enabled = false;
            interrupt0Selection.Enabled = false;
            interrupt1Selection.Enabled = false;

            readTimer.Start();
        }

        private void stopButton_Click(object sender, EventArgs e)
        {
            int returnValue = 0;
            Byte i = 0;

            readTimer.Stop();

            if (boardIntRoutine == 1)
            {
                if (this.board != null)
                {
                    this.board.ResetBoardIntRoutine();
                    boardIntRoutine = 0;
                }
            } 

            for (i = 0; i < 2; i++)
            {
                //Call of the disable function
                if ((returnValue = this.board.DisablePWM(module, i)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in DisablePWM");
                    this.Close();
                    return;
                }
            }

            stopButton.Enabled = false;
            startButton.Enabled = true;
            module0Selection.Enabled = true;
            module1Selection.Enabled = true;
            module2Selection.Enabled = true;
            module3Selection.Enabled = true;
            PWM0Label0.Enabled = true;
            PWM1Label0.Enabled = true;
            timingUnit0Selection.Enabled = true;
            timingUnit1Selection.Enabled = true;
            lowTiming0Selection.Enabled = true;
            lowTiming1Selection.Enabled = true;
            realLow0.Enabled = true;
            realLow1.Enabled = true;
            lowTimingMinMax0.Enabled = true;
            lowTimingMinMax1.Enabled = true;
            highTiming0Selection.Enabled = true;
            highTiming1Selection.Enabled = true;
            realHigh0.Enabled = true;
            realHigh1.Enabled = true;
            highTimingMinMax0.Enabled = true;
            highTimingMinMax1.Enabled = true;
            startLevel0Selection.Enabled = true;
            startLevel1Selection.Enabled = true;
            stopMode0Selection.Enabled = true;
            stopMode1Selection.Enabled = true;
            stopLevel0Selection.Enabled = true;
            stopLevel1Selection.Enabled = true;
            externGate0Selection.Enabled = true;
            externGate1Selection.Enabled = true;
            interrupt0Selection.Enabled = true;
            interrupt1Selection.Enabled = true;
        }

        private void module0Selection_CheckedChanged(object sender, EventArgs e)
        {
            module = 0;

            // Sets all the parameters to their default value
            timingUnit0Selection.Text = timingUnit0Selection.Items[2].ToString();
            timingUnit1Selection.Text = timingUnit1Selection.Items[2].ToString();
            startLevel0Selection.Text = startLevel0Selection.Items[0].ToString();
            startLevel1Selection.Text = startLevel1Selection.Items[0].ToString();
            stopMode0Selection.Text = stopMode0Selection.Items[0].ToString();
            stopMode1Selection.Text = stopMode1Selection.Items[0].ToString();
            stopLevel0Selection.Text = stopLevel0Selection.Items[0].ToString();
            stopLevel1Selection.Text = stopLevel1Selection.Items[0].ToString();
            externGate0Selection.Text = externGate0Selection.Items[0].ToString();
            externGate1Selection.Text = externGate1Selection.Items[0].ToString();
            interrupt0Selection.Text = interrupt0Selection.Items[0].ToString();
            interrupt1Selection.Text = interrupt1Selection.Items[0].ToString();

            // Call the functions to update the values
            timingUnit0Selection_SelectedIndexChanged(null, null);
            timingUnit1Selection_SelectedIndexChanged(null, null);
            if (startButton.Enabled == false)
                stopButton_Click(null, null);
        }

        private void module1Selection_CheckedChanged(object sender, EventArgs e)
        {
            module = 1;

            // Sets all the parameters to their default value
            timingUnit0Selection.Text = timingUnit0Selection.Items[2].ToString();
            timingUnit1Selection.Text = timingUnit1Selection.Items[2].ToString();
            startLevel0Selection.Text = startLevel0Selection.Items[0].ToString();
            startLevel1Selection.Text = startLevel1Selection.Items[0].ToString();
            stopMode0Selection.Text = stopMode0Selection.Items[0].ToString();
            stopMode1Selection.Text = stopMode1Selection.Items[0].ToString();
            stopLevel0Selection.Text = stopLevel0Selection.Items[0].ToString();
            stopLevel1Selection.Text = stopLevel1Selection.Items[0].ToString();
            externGate0Selection.Text = externGate0Selection.Items[0].ToString();
            externGate1Selection.Text = externGate1Selection.Items[0].ToString();
            interrupt0Selection.Text = interrupt0Selection.Items[0].ToString();
            interrupt1Selection.Text = interrupt1Selection.Items[0].ToString();

            // Call the functions to update the values
            timingUnit0Selection_SelectedIndexChanged(null, null);
            timingUnit1Selection_SelectedIndexChanged(null, null);
            if (startButton.Enabled == false)
                stopButton_Click(null, null);
        }

        private void module2Selection_CheckedChanged(object sender, EventArgs e)
        {
            module = 2;

            // Sets all the parameters to their default value
            timingUnit0Selection.Text = timingUnit0Selection.Items[2].ToString();
            timingUnit1Selection.Text = timingUnit1Selection.Items[2].ToString();
            startLevel0Selection.Text = startLevel0Selection.Items[0].ToString();
            startLevel1Selection.Text = startLevel1Selection.Items[0].ToString();
            stopMode0Selection.Text = stopMode0Selection.Items[0].ToString();
            stopMode1Selection.Text = stopMode1Selection.Items[0].ToString();
            stopLevel0Selection.Text = stopLevel0Selection.Items[0].ToString();
            stopLevel1Selection.Text = stopLevel1Selection.Items[0].ToString();
            externGate0Selection.Text = externGate0Selection.Items[0].ToString();
            externGate1Selection.Text = externGate1Selection.Items[0].ToString();
            interrupt0Selection.Text = interrupt0Selection.Items[0].ToString();
            interrupt1Selection.Text = interrupt1Selection.Items[0].ToString();

            // Call the functions to update the values
            timingUnit0Selection_SelectedIndexChanged(null, null);
            timingUnit1Selection_SelectedIndexChanged(null, null);
            if (startButton.Enabled == false)
                stopButton_Click(null, null);
        }

        private void module3Selection_CheckedChanged(object sender, EventArgs e)
        {
            module = 3;

            // Sets all the parameters to their default value
            timingUnit0Selection.Text = timingUnit0Selection.Items[2].ToString();
            timingUnit1Selection.Text = timingUnit1Selection.Items[2].ToString();
            startLevel0Selection.Text = startLevel0Selection.Items[0].ToString();
            startLevel1Selection.Text = startLevel1Selection.Items[0].ToString();
            stopMode0Selection.Text = stopMode0Selection.Items[0].ToString();
            stopMode1Selection.Text = stopMode1Selection.Items[0].ToString();
            stopLevel0Selection.Text = stopLevel0Selection.Items[0].ToString();
            stopLevel1Selection.Text = stopLevel1Selection.Items[0].ToString();
            externGate0Selection.Text = externGate0Selection.Items[0].ToString();
            externGate1Selection.Text = externGate1Selection.Items[0].ToString();
            interrupt0Selection.Text = interrupt0Selection.Items[0].ToString();
            interrupt1Selection.Text = interrupt1Selection.Items[0].ToString();

            // Call the functions to update the values
            timingUnit0Selection_SelectedIndexChanged(null, null);
            timingUnit1Selection_SelectedIndexChanged(null, null);
            if (startButton.Enabled == false)
                stopButton_Click(null, null);
        }
    }
}
