using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ReadPWMDigitalInputs
{
    public partial class ReadPWMDigitalInputs : Form
    {
        /// <summary>
        /// Handle to the first board
        /// </summary>
        PCI1710_NET.PCI1710 board;
        Byte module;

        /// <summary>
        /// Usefull variable used to access the input status picture
        /// </summary>
        PictureBox[] inputStatusBox;

        /// <summary>
        /// Constructor of the form
        /// </summary>
        public ReadPWMDigitalInputs()
        {
            InitializeComponent();

            module = 0;
            inputStatusBox = new PictureBox[3];
            inputStatusBox[0] = inputE;
            inputStatusBox[1] = inputF;
            inputStatusBox[2] = inputG;
        }

        /// <summary>
        /// Call at the first load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ReadPWMDigitalInputs_Load(object sender, EventArgs e)
        {
            module0Selection.Checked = true;

            // Open the first board of the system
            this.board = PCI1710_NET.PCI1710.OpenBoard(0);
            // Error handling
            if (this.board == null)
            {
                MessageBox.Show("Error OpenBoard returned null");
                this.Close();
                return;
            }

            // Start the timer
            this.readTimer.Start();
        }

        /// <summary>
        /// The read timer ticks
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void readTimer_Tick(object sender, EventArgs e)
        {
            int returnValue = 0;
            byte inputStatus = 0;
            // We read the status of the outputs
            if ((returnValue = this.board.ReadPWMAllDigitalInputs(module, out inputStatus)) != 0)
            {
                MessageBox.Show("Error " + returnValue.ToString() + " in ReadPWMAllDigitalInputs");
                this.Close();
                return;
            }

            // We change the image given the new status
            for (int i = 0; i < 3; i++)
            {
                if (((inputStatus >> i) & 1) == 1)
                    inputStatusBox[i].Image = global::ReadPWMDigitalInputs.Properties.Resources.led_on;
                else
                    inputStatusBox[i].Image = global::ReadPWMDigitalInputs.Properties.Resources.led_off;
            }

            this.ResumeLayout(false);
            this.PerformLayout();
        }

        /// <summary>
        /// Occurs when the user closes the form
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ReadPWMDigitalInputs_FormClosing(object sender, FormClosingEventArgs e)
        {
            // Stop the timer
            this.readTimer.Stop();
        }

        private void module0Selection_CheckedChanged(object sender, EventArgs e)
        {
            if (module0Selection.Checked == true)
                module = 0;
        }

        private void module1Selection_CheckedChanged(object sender, EventArgs e)
        {
            if (module1Selection.Checked == true)
                module = 1;
        }

        private void module2Selection_CheckedChanged(object sender, EventArgs e)
        {
            if (module2Selection.Checked == true)
                module = 2;
        }

        private void module3Selection_CheckedChanged(object sender, EventArgs e)
        {
            if (module3Selection.Checked == true)
                module = 3;
        }
    }
}
