using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace SetPWMDigitalOutputs
{
    public partial class SetPWMDigitalOutputs : Form
    {
        /// <summary>
        /// Handle to the first board
        /// </summary>
        PCI1710_NET.PCI1710 board;
        Byte module;
        Byte oldModule;

        /// <summary>
        /// Constructor of the form
        /// </summary>
        public SetPWMDigitalOutputs()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Call at the first load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SetPWMDigitalOutputs_Load(object sender, EventArgs e)
        {
            int returnValue = 0;
            UInt32 realLTiming = 0;
            UInt32 realHTiming = 0;
            module = 0;
            oldModule = 0;

            // Open the first board of the system
            this.board = PCI1710_NET.PCI1710.OpenBoard(0);
            // Error handling
            if (this.board == null)
            {
                MessageBox.Show("Error OpenBoard returned null");
                this.Close();
                return;
            }

            // Call of the init function
            if ((returnValue = this.board.InitPWM(module, 0 /* PWM 0 */, 3 /* Timing unit (sec) */, 1 /* Low timing value */, 2 /* High timing value */, out realLTiming, out realHTiming)) != 0)
            {
                MessageBox.Show("Error " + returnValue.ToString() + " in InitPWM");
                this.Close();
                return;
            }

            // Call of the enable function
            if ((returnValue = this.board.EnablePWM(module, 0 /* PWM 0 */, 0 /* Start level */, 1 /* Stop mode */, 1 /* Stop level */, 0 /*Extern gate */, 0 /* Interrupt */)) != 0)
            {
                MessageBox.Show("Error " + returnValue.ToString() + " in EnablePWM");
                this.Close();
                return;
            }

            module0Selection.Checked = true;
            //manualSetting.Text = manualSetting.Items[1].ToString();
            resetButton.Checked = true;
        }

        /// <summary>
        /// Occurs when the user closes the form
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SetPWMDigitalOutputs_FormClosing(object sender, FormClosingEventArgs e)
        {
            int returnValue = 0;
            Byte i = 0;

            // Call of the disable function
            if ((returnValue = this.board.DisablePWM(module, 0 /* PWM 0 */)) != 0)
            {
                MessageBox.Show("Error " + returnValue.ToString() + " in DisablePWM");
                this.Close();
                return;
            }

            // Reset all the outputs
            for (i = 0; i < 4; i++)
            {
                // Call of the enableDisablePWMDigitalOutputManualSetting function
                if ((returnValue = this.board.EnableDisablePWMDigitalOutputManualSetting(i, 1 /* Set the manual setting */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue + " in EnableDisablePWMDigitalOutputManualSetting");
                    this.Close();
                    return;
                }

                // Call of the setDigitalOutputOff function
                if ((returnValue = this.board.SetPWMDigitalOutputOff(i)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in SetPWMDigitalOutputOff");
                    this.Close();
                    return;
                }

                // Call of the enableDisablePWMDigitalOutputManualSetting function
                if ((returnValue = this.board.EnableDisablePWMDigitalOutputManualSetting(i, 0 /* Reset the manual setting */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue + " in EnableDisablePWMDigitalOutputManualSetting");
                    this.Close();
                    return;
                }
            }
        }

        private void manualSetting_SelectedIndexChanged(object sender, EventArgs e)
        {
            int returnValue = 0;

            if (manualSetting.SelectedIndex == 0)
            {
                setButton.Enabled = false;
                resetButton.Enabled = false;

                // Call of the enableDisablePWMDigitalOutputManualSetting function
                if ((returnValue = this.board.EnableDisablePWMDigitalOutputManualSetting(module, 0 /* Reset the manual setting */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue + " in EnableDisablePWMDigitalOutputManualSetting");
                    this.Close();
                    return;
                }

                setButton.Checked = false;
                resetButton.Checked = false;
            }
            else if (manualSetting.SelectedIndex == 1)
            {
                setButton.Enabled = true;
                resetButton.Enabled = true;

                // Call of the enableDisablePWMDigitalOutputManualSetting function
                if ((returnValue = this.board.EnableDisablePWMDigitalOutputManualSetting(module, 1 /* Set the manual setting */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue + " in EnableDisablePWMDigitalOutputManualSetting");
                    this.Close();
                    return;
                }

                resetButton.Checked = true;
            }
        }

        private void setButton_CheckedChanged(object sender, EventArgs e)
        {
            int returnValue = 0;

            if (setButton.Checked == true)
            {
                // Call of the setDigitalOutputOn function
                if ((returnValue = this.board.SetPWMDigitalOutputOn(module)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in SetPWMDigitalOutputOn");
                    this.Close();
                    return;
                }
            }
        }

        private void resetButton_CheckedChanged(object sender, EventArgs e)
        {
            int returnValue = 0;

            if (resetButton.Checked == true)
            {
                // Call of the setDigitalOutputOff function
                if ((returnValue = this.board.SetPWMDigitalOutputOff(module)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in SetPWMDigitalOutputOff");
                    this.Close();
                    return;
                }
            }
        }

        private void module0Selection_CheckedChanged(object sender, EventArgs e)
        {
            int returnValue = 0;
            UInt32 realLTiming = 0;
            UInt32 realHTiming = 0;

            if (module0Selection.Checked == true)
            {
                if (module0Selection.Checked == true)
                    module = 0;

                // Call of the disable function
                if ((returnValue = this.board.DisablePWM(oldModule, 0 /* PWM 0 */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in DisablePWM");
                    this.Close();
                    return;
                }

                // Call of the init function
                if ((returnValue = this.board.InitPWM(module, 0 /* PWM 0 */, 3 /* Timing unit (sec) */, 1 /* Low timing value */, 2 /* High timing value */, out realLTiming, out realHTiming)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in InitPWM");
                    this.Close();
                    return;
                }

                // Call of the enable function
                if ((returnValue = this.board.EnablePWM(module, 0 /* PWM 0 */, 0 /* Start level */, 1 /* Stop mode */, 1 /* Stop level */, 0 /*Extern gate */, 0 /* Interrupt */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in EnablePWM");
                    this.Close();
                    return;
                }

                manualSetting.Text = manualSetting.Items[1].ToString();
                manualSetting_SelectedIndexChanged(null, null);
                resetButton.Checked = true;
                resetButton_CheckedChanged(null, null);

                oldModule = 0;
            }
        }

        private void module1Selection_CheckedChanged(object sender, EventArgs e)
        {
            int returnValue = 0;
            UInt32 realLTiming = 0;
            UInt32 realHTiming = 0;

            if (module1Selection.Checked == true)
            {
                if (module1Selection.Checked == true)
                    module = 1;

                // Call of the disable function
                if ((returnValue = this.board.DisablePWM(oldModule, 0 /* PWM 0 */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in DisablePWM");
                    this.Close();
                    return;
                }

                // Call of the init function
                if ((returnValue = this.board.InitPWM(module, 0 /* PWM 0 */, 3 /* Timing unit (sec) */, 1 /* Low timing value */, 2 /* High timing value */, out realLTiming, out realHTiming)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in InitPWM");
                    this.Close();
                    return;
                }

                // Call of the enable function
                if ((returnValue = this.board.EnablePWM(module, 0 /* PWM 0 */, 0 /* Start level */, 1 /* Stop mode */, 1 /* Stop level */, 0 /*Extern gate */, 0 /* Interrupt */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in EnablePWM");
                    this.Close();
                    return;
                }

                manualSetting.Text = manualSetting.Items[1].ToString();
                manualSetting_SelectedIndexChanged(null, null);
                resetButton.Checked = true;
                resetButton_CheckedChanged(null, null);

                oldModule = 1;
            }
        }

        private void module2Selection_CheckedChanged(object sender, EventArgs e)
        {
            int returnValue = 0;
            UInt32 realLTiming = 0;
            UInt32 realHTiming = 0;

            if (module2Selection.Checked == true)
            {
                if (module2Selection.Checked == true)
                    module = 2;

                // Call of the disable function
                if ((returnValue = this.board.DisablePWM(oldModule, 0 /* PWM 0 */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in DisablePWM");
                    this.Close();
                    return;
                }

                // Call of the init function
                if ((returnValue = this.board.InitPWM(module, 0 /* PWM 0 */, 3 /* Timing unit (sec) */, 1 /* Low timing value */, 2 /* High timing value */, out realLTiming, out realHTiming)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in InitPWM");
                    this.Close();
                    return;
                }

                // Call of the enable function
                if ((returnValue = this.board.EnablePWM(module, 0 /* PWM 0 */, 0 /* Start level */, 1 /* Stop mode */, 1 /* Stop level */, 0 /*Extern gate */, 0 /* Interrupt */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in EnablePWM");
                    this.Close();
                    return;
                }

                manualSetting.Text = manualSetting.Items[1].ToString();
                manualSetting_SelectedIndexChanged(null, null);
                resetButton.Checked = true;
                resetButton_CheckedChanged(null, null);

                oldModule = 2;
            }
        }

        private void module3Selection_CheckedChanged(object sender, EventArgs e)
        {
            int returnValue = 0;
            UInt32 realLTiming = 0;
            UInt32 realHTiming = 0;

            if (module3Selection.Checked == true)
            {
                if (module3Selection.Checked == true)
                    module = 3;

                // Call of the disable function
                if ((returnValue = this.board.DisablePWM(oldModule, 0 /* PWM 0 */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in DisablePWM");
                    this.Close();
                    return;
                }
                
                // Call of the init function
                if ((returnValue = this.board.InitPWM(module, 0 /* PWM 0 */, 3 /* Timing unit (sec) */, 1 /* Low timing value */, 2 /* High timing value */, out realLTiming, out realHTiming)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in InitPWM");
                    this.Close();
                    return;
                }

                // Call of the enable function
                if ((returnValue = this.board.EnablePWM(module, 0 /* PWM 0 */, 0 /* Start level */, 1 /* Stop mode */, 1 /* Stop level */, 0 /*Extern gate */, 0 /* Interrupt */)) != 0)
                {
                    MessageBox.Show("Error " + returnValue.ToString() + " in EnablePWM");
                    this.Close();
                    return;
                }

                manualSetting.Text = manualSetting.Items[1].ToString();
                manualSetting_SelectedIndexChanged(null, null);
                resetButton.Checked = true;
                resetButton_CheckedChanged(null, null);

                oldModule = 3;
            }
        }
    }
}
