//##protect##"FileHeader"
/** @file i_PCI1710_mexConvertETMValue.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 24.07.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexConvertETMValue MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexConvertETMValue */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	DWORD ETMValue = 0;
	DWORD *hour = mxCalloc(1, sizeof(DWORD));
	BYTE *minute = mxCalloc(1, sizeof(BYTE));
	BYTE *second = mxCalloc(1, sizeof(BYTE));
	DWORD *millisecond = mxCalloc(1, sizeof(DWORD));
	DWORD *microsecond = mxCalloc(1, sizeof(DWORD));
	DWORD *nanosecond = mxCalloc(1, sizeof(DWORD));
//##protect##"i_PCI1710_mexConvertETMValue_VariablesDefinition"
//##protect##"i_PCI1710_mexConvertETMValue_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 3)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexConvertETMValue:nrhs", "3 inputs are required.\n");
	if (nlhs != 7)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexConvertETMValue:nlhs", "7 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	ETMValue = (DWORD)mxGetScalar(prhs[2]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexConvertETMValue:nlhs", "The moduleNumber input must be between 0 and 3.\n");

//##protect##"i_PCI1710_mexConvertETMValue_Start"
//##protect##"i_PCI1710_mexConvertETMValue_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_ConvertETMValue(deviceHandle, moduleNumber, ETMValue, hour, minute, second, millisecond, microsecond, nanosecond);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[1], hour);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);
	plhs[2] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[2], minute);  mxSetM(plhs[2], 1);  mxSetN(plhs[2], 1);
	plhs[3] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[3], second);  mxSetM(plhs[3], 1);  mxSetN(plhs[3], 1);
	plhs[4] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[4], millisecond);  mxSetM(plhs[4], 1);  mxSetN(plhs[4], 1);
	plhs[5] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[5], microsecond);  mxSetM(plhs[5], 1);  mxSetN(plhs[5], 1);
	plhs[6] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[6], nanosecond);  mxSetM(plhs[6], 1);  mxSetN(plhs[6], 1);

//##protect##"i_PCI1710_mexConvertETMValue_End"
//##protect##"i_PCI1710_mexConvertETMValue_End"
}
