//##protect##"FileHeader"
/** @file i_PCI1710_mexEnableETM.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 24.07.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexEnableETM MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexEnableETM */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE ETM = 0;
	BYTE edgeLevel = 0;
	BYTE triggerLevel = 0;
	BYTE cycleMode = 0;
	BYTE firstTriggerMode = 0;
	BYTE interruptEnable = 0;
//##protect##"i_PCI1710_mexEnableETM_VariablesDefinition"
//##protect##"i_PCI1710_mexEnableETM_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 8)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nrhs", "8 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	ETM = (BYTE)mxGetScalar(prhs[2]);
	edgeLevel = (BYTE)mxGetScalar(prhs[3]);
	triggerLevel = (BYTE)mxGetScalar(prhs[4]);
	cycleMode = (BYTE)mxGetScalar(prhs[5]);
	firstTriggerMode = (BYTE)mxGetScalar(prhs[6]);
	interruptEnable = (BYTE)mxGetScalar(prhs[7]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((ETM < 0) || (ETM > 2))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "The ETM input must be between 0 and 2.\n");
	if ((edgeLevel < 0) || (edgeLevel > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "The edgeLevel input must be between 0 and 1.\n");
	if ((triggerLevel < 0) || (triggerLevel > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "The triggerLevel input must be between 0 and 1.\n");
	if ((cycleMode < 0) || (cycleMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "The cycleMode input must be between 0 and 1.\n");
	if ((firstTriggerMode < 0) || (firstTriggerMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "The firstTriggerMode input must be between 0 and 1.\n");
	if ((interruptEnable < 0) || (interruptEnable > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnableETM:nlhs", "The interruptEnable input must be between 0 and 1.\n");

//##protect##"i_PCI1710_mexEnableETM_Start"
//##protect##"i_PCI1710_mexEnableETM_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_EnableETM(deviceHandle, moduleNumber, ETM, edgeLevel, triggerLevel, cycleMode, firstTriggerMode, interruptEnable);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCI1710_mexEnableETM_End"
//##protect##"i_PCI1710_mexEnableETM_End"
}
