//##protect##"FileHeader"
/** @file i_PCI1710_mexEnablePWM.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 24.07.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexEnablePWM MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexEnablePWM */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE PWM = 0;
	BYTE startLevel = 0;
	BYTE stopMode = 0;
	BYTE stopLevel = 0;
	BYTE externGate = 0;
	BYTE interruptEnable = 0;
//##protect##"i_PCI1710_mexEnablePWM_VariablesDefinition"
//##protect##"i_PCI1710_mexEnablePWM_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 8)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nrhs", "8 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	PWM = (BYTE)mxGetScalar(prhs[2]);
	startLevel = (BYTE)mxGetScalar(prhs[3]);
	stopMode = (BYTE)mxGetScalar(prhs[4]);
	stopLevel = (BYTE)mxGetScalar(prhs[5]);
	externGate = (BYTE)mxGetScalar(prhs[6]);
	interruptEnable = (BYTE)mxGetScalar(prhs[7]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((PWM < 0) || (PWM > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "The PWM input must be between 0 and 1.\n");
	if ((startLevel < 0) || (startLevel > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "The startLevel input must be between 0 and 1.\n");
	if ((stopMode < 0) || (stopMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "The stopMode input must be between 0 and 1.\n");
	if ((stopLevel < 0) || (stopLevel > 2))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "The stopLevel input must be between 0 and 2.\n");
	if ((externGate < 0) || (externGate > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "The externGate input must be between 0 and 1.\n");
	if ((interruptEnable < 0) || (interruptEnable > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexEnablePWM:nlhs", "The interruptEnable input must be between 0 and 1.\n");

//##protect##"i_PCI1710_mexEnablePWM_Start"
//##protect##"i_PCI1710_mexEnablePWM_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_EnablePWM(deviceHandle, moduleNumber, PWM, startLevel, stopMode, stopLevel, externGate, interruptEnable);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCI1710_mexEnablePWM_End"
//##protect##"i_PCI1710_mexEnablePWM_End"
}
