//##protect##"FileHeader"
/** @file i_PCI1710_mexGetPWMInitialisation.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 24.07.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexGetPWMInitialisation MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexGetPWMInitialisation */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE PWM = 0;
	BYTE *timingUnit = mxCalloc(1, sizeof(BYTE));
	DWORD *lowTiming = mxCalloc(1, sizeof(DWORD));
	DWORD *highTiming = mxCalloc(1, sizeof(DWORD));
	BYTE *startLevel = mxCalloc(1, sizeof(BYTE));
	BYTE *stopMode = mxCalloc(1, sizeof(BYTE));
	BYTE *stopLevel = mxCalloc(1, sizeof(BYTE));
	BYTE *externGate = mxCalloc(1, sizeof(BYTE));
	BYTE *interruptEnable = mxCalloc(1, sizeof(BYTE));
	BYTE *enable = mxCalloc(1, sizeof(BYTE));
//##protect##"i_PCI1710_mexGetPWMInitialisation_VariablesDefinition"
//##protect##"i_PCI1710_mexGetPWMInitialisation_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 3)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexGetPWMInitialisation:nrhs", "3 inputs are required.\n");
	if (nlhs != 10)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexGetPWMInitialisation:nlhs", "10 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	PWM = (BYTE)mxGetScalar(prhs[2]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexGetPWMInitialisation:nlhs", "The moduleNumber input must be between 0 and 3.\n");

//##protect##"i_PCI1710_mexGetPWMInitialisation_Start"
//##protect##"i_PCI1710_mexGetPWMInitialisation_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_GetPWMInitialisation(deviceHandle, moduleNumber, PWM, timingUnit, lowTiming, highTiming, startLevel, stopMode, stopLevel, externGate, interruptEnable, enable);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[1], timingUnit);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);
	plhs[2] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[2], lowTiming);  mxSetM(plhs[2], 1);  mxSetN(plhs[2], 1);
	plhs[3] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[3], highTiming);  mxSetM(plhs[3], 1);  mxSetN(plhs[3], 1);
	plhs[4] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[4], startLevel);  mxSetM(plhs[4], 1);  mxSetN(plhs[4], 1);
	plhs[5] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[5], stopMode);  mxSetM(plhs[5], 1);  mxSetN(plhs[5], 1);
	plhs[6] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[6], stopLevel);  mxSetM(plhs[6], 1);  mxSetN(plhs[6], 1);
	plhs[7] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[7], externGate);  mxSetM(plhs[7], 1);  mxSetN(plhs[7], 1);
	plhs[8] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[8], interruptEnable);  mxSetM(plhs[8], 1);  mxSetN(plhs[8], 1);
	plhs[9] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[9], enable);  mxSetM(plhs[9], 1);  mxSetN(plhs[9], 1);

//##protect##"i_PCI1710_mexGetPWMInitialisation_End"
//##protect##"i_PCI1710_mexGetPWMInitialisation_End"
}
