function [returnValue, timingUnit, lowTiming, highTiming, startLevel, stopMode, stopLevel, externGate, interruptEnable, enable] = i_PCI1710_mexGetPWMInitialisation(deviceHandle, moduleNumber, PWM)
% i_PCI1710_mexGetPWMInitialisation
%
% Returns the selected PWM initialization of the selected module.
% The i_PCI1710_InitPWM function must be called before calling this function.
%
% Input parameters:
%    deviceHandle              "Handle of the board"
%    moduleNumber              "Number of the module to be configured (from 0 to 3)"
%    PWM                       "Selected PWM (0 or 1)"
%
% Output parameters:
%    returnValue               "Value returned by the function"
%    timingUnit                "Returns the base timing unit (0: ns, 1: us, 2: ms, 3: sec or 4: min)"
%    lowTiming                 "Returns the low base timing value"
%    highTiming                "Returns the high base timing value"
%    startLevel                "Returns the start period level selection (0: the period will start with a low level, 1: the period will start with a high level)"
%    stopMode                  "Returns the stop mode selection (0: the PWM will be stopped directly after the call of the i_PCI1710_DisablePWM function and will break the last period, 1: the PWM will end its last period before being stopped after the call of the disable function)"
%    stopLevel                 "Returns the stop level selection (0: the output signal will keep the level after the call of the i_PCI1710_DisablePWM function, 1: the output signal will be stopped at low after the call of the disable function, 2: the output signal will be set to high after the call of the disable function)"
%    externGate                "Indicates if the extern gate action is used (0: not used, 1: used)"
%    interruptEnable           "Indicates if the interrupt are enabled or not (0: disabled, 1: enabled)"
%    enable                    "Indicates if the PWM is enabled or not (0: disabled, 1: enabled)"
%
%Example:
% // Add an example here

[returnValue, timingUnit, lowTiming, highTiming, startLevel, stopMode, stopLevel, externGate, interruptEnable, enable] = i_PCI1710_mexGetPWMInitialisation(deviceHandle, moduleNumber, PWM);
