//##protect##"FileHeader"
/** @file i_PCI1710_mexInitCounter.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 31.01.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexInitCounter MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexInitCounter */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE counterRange = 0;
	BYTE firstCounterModus = 0;
	BYTE firstCounterOption = 0;
	BYTE secondCounterModus = 0;
	BYTE secondCounterOption = 0;
//##protect##"i_PCI1710_mexInitCounter_VariablesDefinition"
//##protect##"i_PCI1710_mexInitCounter_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 7)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nrhs", "7 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	counterRange = (BYTE)mxGetScalar(prhs[2]);
	firstCounterModus = (BYTE)mxGetScalar(prhs[3]);
	firstCounterOption = (BYTE)mxGetScalar(prhs[4]);
	secondCounterModus = (BYTE)mxGetScalar(prhs[5]);
	secondCounterOption = (BYTE)mxGetScalar(prhs[6]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if (counterRange == 0 && counterRange == 16)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nlhs", "The counterRange input must be strictly equal to 0 or strictly equal to 16.\n");
	if (firstCounterModus == 0 && firstCounterModus == 3 && firstCounterModus == 15 && firstCounterModus == 128)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nlhs", "The firstCounterModus input must be strictly equal to 0 or strictly equal to 3 or strictly equal to 15 or strictly equal to 128.\n");
	if (firstCounterOption == 0 && firstCounterOption == 96)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nlhs", "The firstCounterOption input must be strictly equal to 0 or strictly equal to 96.\n");
	if (secondCounterModus == 0 && secondCounterModus == 3 && secondCounterModus == 15 && secondCounterModus == 128)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nlhs", "The secondCounterModus input must be strictly equal to 0 or strictly equal to 3 or strictly equal to 15 or strictly equal to 128.\n");
	if (secondCounterOption == 0 && secondCounterOption == 96)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitCounter:nlhs", "The secondCounterOption input must be strictly equal to 0 or strictly equal to 96.\n");

//##protect##"i_PCI1710_mexInitCounter_Start"
//##protect##"i_PCI1710_mexInitCounter_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_InitCounter(deviceHandle, moduleNumber, counterRange, firstCounterModus, firstCounterOption, secondCounterModus, secondCounterOption);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCI1710_mexInitCounter_End"
//##protect##"i_PCI1710_mexInitCounter_End"
}
