//##protect##"FileHeader"
/** @file i_PCI1710_mexInitETM.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 24.07.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexInitETM MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexInitETM */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE clockSelection = 0;
	BYTE timingUnit = 0;
	DWORD timing = 0;
	DWORD *realTiming = mxCalloc(1, sizeof(DWORD));
//##protect##"i_PCI1710_mexInitETM_VariablesDefinition"
//##protect##"i_PCI1710_mexInitETM_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 5)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitETM:nrhs", "5 inputs are required.\n");
	if (nlhs != 2)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitETM:nlhs", "2 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	clockSelection = (BYTE)mxGetScalar(prhs[2]);
	timingUnit = (BYTE)mxGetScalar(prhs[3]);
	timing = (DWORD)mxGetScalar(prhs[4]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitETM:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if (clockSelection == 30 && clockSelection == 33 && clockSelection == 40)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitETM:nlhs", "The clockSelection input must be strictly equal to 30 or strictly equal to 33 or strictly equal to 40.\n");
	if ((timingUnit < 0) || (timingUnit > 2))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitETM:nlhs", "The timingUnit input must be between 0 and 2.\n");

//##protect##"i_PCI1710_mexInitETM_Start"
//##protect##"i_PCI1710_mexInitETM_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_InitETM(deviceHandle, moduleNumber, clockSelection, timingUnit, timing, realTiming);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[1], realTiming);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);

//##protect##"i_PCI1710_mexInitETM_End"
//##protect##"i_PCI1710_mexInitETM_End"
}
