//##protect##"FileHeader"
/** @file i_PCI1710_mexInitIndex.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 31.01.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexInitIndex MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexInitIndex */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE referenceAction = 0;
	BYTE indexOperation = 0;
	BYTE autoMode = 0;
	BYTE interruptEnable = 0;
//##protect##"i_PCI1710_mexInitIndex_VariablesDefinition"
//##protect##"i_PCI1710_mexInitIndex_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 6)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitIndex:nrhs", "6 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitIndex:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	referenceAction = (BYTE)mxGetScalar(prhs[2]);
	indexOperation = (BYTE)mxGetScalar(prhs[3]);
	autoMode = (BYTE)mxGetScalar(prhs[4]);
	interruptEnable = (BYTE)mxGetScalar(prhs[5]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitIndex:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((referenceAction < 0) || (referenceAction > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitIndex:nlhs", "The referenceAction input must be between 0 and 1.\n");
	if ((indexOperation < 0) || (indexOperation > 5))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitIndex:nlhs", "The indexOperation input must be between 0 and 5.\n");
	if ((autoMode < 0) || (autoMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitIndex:nlhs", "The autoMode input must be between 0 and 1.\n");
	if ((interruptEnable < 0) || (interruptEnable > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitIndex:nlhs", "The interruptEnable input must be between 0 and 1.\n");

//##protect##"i_PCI1710_mexInitIndex_Start"
//##protect##"i_PCI1710_mexInitIndex_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_InitIndex(deviceHandle, moduleNumber, referenceAction, indexOperation, autoMode, interruptEnable);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCI1710_mexInitIndex_End"
//##protect##"i_PCI1710_mexInitIndex_End"
}
