//##protect##"FileHeader"
/** @file i_PCI1710_mexInitPWM.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 24.07.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexInitPWM MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexInitPWM */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE PWM = 0;
	BYTE timingUnit = 0;
	DWORD lowTiming = 0;
	DWORD highTiming = 0;
	DWORD *realLowTiming = mxCalloc(1, sizeof(DWORD));
	DWORD *realHighTiming = mxCalloc(1, sizeof(DWORD));
//##protect##"i_PCI1710_mexInitPWM_VariablesDefinition"
//##protect##"i_PCI1710_mexInitPWM_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 6)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitPWM:nrhs", "6 inputs are required.\n");
	if (nlhs != 3)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitPWM:nlhs", "3 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	PWM = (BYTE)mxGetScalar(prhs[2]);
	timingUnit = (BYTE)mxGetScalar(prhs[3]);
	lowTiming = (DWORD)mxGetScalar(prhs[4]);
	highTiming = (DWORD)mxGetScalar(prhs[5]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitPWM:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((PWM < 0) || (PWM > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitPWM:nlhs", "The PWM input must be between 0 and 1.\n");
	if ((timingUnit < 0) || (timingUnit > 4))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitPWM:nlhs", "The timingUnit input must be between 0 and 4.\n");

//##protect##"i_PCI1710_mexInitPWM_Start"
//##protect##"i_PCI1710_mexInitPWM_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_InitPWM(deviceHandle, moduleNumber, PWM, timingUnit, lowTiming, highTiming, realLowTiming, realHighTiming);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[1], realLowTiming);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);
	plhs[2] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[2], realHighTiming);  mxSetM(plhs[2], 1);  mxSetN(plhs[2], 1);

//##protect##"i_PCI1710_mexInitPWM_End"
//##protect##"i_PCI1710_mexInitPWM_End"
}
