//##protect##"FileHeader"
/** @file i_PCI1710_mexInitSSI.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 25.10.2012
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexInitSSI MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexInitSSI */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE profileLength = 0;
	BYTE positionLength = 0;
	BYTE turnCptLength = 0;
	BYTE PCIInputClock = 0;
	DWORD outputClock = 0;
	BYTE countingMode = 0;
//##protect##"i_PCI1710_mexInitSSI_VariablesDefinition"
//##protect##"i_PCI1710_mexInitSSI_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 8)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nrhs", "8 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	profileLength = (BYTE)mxGetScalar(prhs[2]);
	positionLength = (BYTE)mxGetScalar(prhs[3]);
	turnCptLength = (BYTE)mxGetScalar(prhs[4]);
	PCIInputClock = (BYTE)mxGetScalar(prhs[5]);
	outputClock = (DWORD)mxGetScalar(prhs[6]);
	countingMode = (BYTE)mxGetScalar(prhs[7]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((profileLength < 2) || (profileLength > 32))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nlhs", "The profileLength input must be between 2 and 32.\n");
	if ((turnCptLength < 0) || (turnCptLength > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nlhs", "The turnCptLength input must be between 0 and 1.\n");
	if (PCIInputClock == 30 && PCIInputClock == 33)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nlhs", "The PCIInputClock input must be strictly equal to 30 or strictly equal to 33.\n");
	if ((outputClock < 229) || (outputClock > 5000000))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nlhs", "The outputClock input must be between 229 and 5000000.\n");
	if ((countingMode < 0) || (countingMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitSSI:nlhs", "The countingMode input must be between 0 and 1.\n");

//##protect##"i_PCI1710_mexInitSSI_Start"
//##protect##"i_PCI1710_mexInitSSI_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_InitSSI(deviceHandle, moduleNumber, profileLength, positionLength, turnCptLength, PCIInputClock, outputClock, countingMode);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCI1710_mexInitSSI_End"
//##protect##"i_PCI1710_mexInitSSI_End"
}
