//##protect##"FileHeader"
/** @file i_PCI1710_mexInitTimer.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 31.01.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexInitTimer MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexInitTimer */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE timerNumber = 0;
	BYTE timerMode = 0;
	DWORD reloadValue = 0;
	BYTE inputClockSelection = 0;
	BYTE inputClockLevel = 0;
	BYTE outputLevel = 0;
	BYTE hardwareGateLevel = 0;
//##protect##"i_PCI1710_mexInitTimer_VariablesDefinition"
//##protect##"i_PCI1710_mexInitTimer_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 9)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nrhs", "9 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	timerNumber = (BYTE)mxGetScalar(prhs[2]);
	timerMode = (BYTE)mxGetScalar(prhs[3]);
	reloadValue = (DWORD)mxGetScalar(prhs[4]);
	inputClockSelection = (BYTE)mxGetScalar(prhs[5]);
	inputClockLevel = (BYTE)mxGetScalar(prhs[6]);
	outputLevel = (BYTE)mxGetScalar(prhs[7]);
	hardwareGateLevel = (BYTE)mxGetScalar(prhs[8]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((timerNumber < 0) || (timerNumber > 2))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The timerNumber input must be between 0 and 2.\n");
	if ((timerMode < 0) || (timerMode > 5))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The timerMode input must be between 0 and 5.\n");
	if ((reloadValue < 0) || (reloadValue > 4294967295))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The reloadValue input must be between 0 and 4294967295.\n");
	if ((inputClockSelection < 1) || (inputClockSelection > 2))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The inputClockSelection input must be between 1 and 2.\n");
	if ((inputClockLevel < 0) || (inputClockLevel > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The inputClockLevel input must be between 0 and 1.\n");
	if ((outputLevel < 0) || (outputLevel > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The outputLevel input must be between 0 and 1.\n");
	if ((hardwareGateLevel < 0) || (hardwareGateLevel > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexInitTimer:nlhs", "The hardwareGateLevel input must be between 0 and 1.\n");

//##protect##"i_PCI1710_mexInitTimer_Start"
//##protect##"i_PCI1710_mexInitTimer_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_InitTimer(deviceHandle, moduleNumber, timerNumber, timerMode, reloadValue, inputClockSelection, inputClockLevel, outputLevel, hardwareGateLevel);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCI1710_mexInitTimer_End"
//##protect##"i_PCI1710_mexInitTimer_End"
}
