//##protect##"FileHeader"
/** @file i_PCI1710_mexRead1SSIValue.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 01.02.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexRead1SSIValue MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexRead1SSIValue */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE SSINbr = 0;
	DWORD *position = mxCalloc(1, sizeof(DWORD));
	DWORD *turn = mxCalloc(1, sizeof(DWORD));
//##protect##"i_PCI1710_mexRead1SSIValue_VariablesDefinition"
//##protect##"i_PCI1710_mexRead1SSIValue_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 3)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexRead1SSIValue:nrhs", "3 inputs are required.\n");
	if (nlhs != 3)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexRead1SSIValue:nlhs", "3 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	SSINbr = (BYTE)mxGetScalar(prhs[2]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexRead1SSIValue:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((SSINbr < 0) || (SSINbr > 2))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexRead1SSIValue:nlhs", "The SSINbr input must be between 0 and 2.\n");

//##protect##"i_PCI1710_mexRead1SSIValue_Start"
//##protect##"i_PCI1710_mexRead1SSIValue_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_Read1SSIValue(deviceHandle, moduleNumber, SSINbr, position, turn);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[1], position);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);
	plhs[2] = mxCreateNumericArray(0, NULL, mxUINT32_CLASS, mxREAL);
	mxSetData(plhs[2], turn);  mxSetM(plhs[2], 1);  mxSetN(plhs[2], 1);

//##protect##"i_PCI1710_mexRead1SSIValue_End"
//##protect##"i_PCI1710_mexRead1SSIValue_End"
}
