//##protect##"FileHeader"
/** @file i_PCI1710_mexReadPWM1DigitalInput.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 24.07.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexReadPWM1DigitalInput MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexReadPWM1DigitalInput */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE modulNbr = 0;
	BYTE inputChannel = 0;
	BYTE *channelStatus = mxCalloc(1, sizeof(BYTE));
//##protect##"i_PCI1710_mexReadPWM1DigitalInput_VariablesDefinition"
//##protect##"i_PCI1710_mexReadPWM1DigitalInput_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 3)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadPWM1DigitalInput:nrhs", "3 inputs are required.\n");
	if (nlhs != 2)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadPWM1DigitalInput:nlhs", "2 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	modulNbr = (BYTE)mxGetScalar(prhs[1]);
	inputChannel = (BYTE)mxGetScalar(prhs[2]);

	/* Check of the values of the input parameters */
	if ((modulNbr < 0) || (modulNbr > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadPWM1DigitalInput:nlhs", "The modulNbr input must be between 0 and 3.\n");
	if ((inputChannel < 0) || (inputChannel > 2))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadPWM1DigitalInput:nlhs", "The inputChannel input must be between 0 and 2.\n");

//##protect##"i_PCI1710_mexReadPWM1DigitalInput_Start"
//##protect##"i_PCI1710_mexReadPWM1DigitalInput_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_ReadPWM1DigitalInput(deviceHandle, modulNbr, inputChannel, channelStatus);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[1], channelStatus);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);

//##protect##"i_PCI1710_mexReadPWM1DigitalInput_End"
//##protect##"i_PCI1710_mexReadPWM1DigitalInput_End"
}
