//##protect##"FileHeader"
/** @file i_PCI1710_mexReadTTLIOChannelValue.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 25.10.2012
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexReadTTLIOChannelValue MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexReadTTLIOChannelValue */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE portNbr = 0;
	BYTE channelNbr = 0;
	BYTE *value = mxCalloc(1, sizeof(BYTE));
//##protect##"i_PCI1710_mexReadTTLIOChannelValue_VariablesDefinition"
//##protect##"i_PCI1710_mexReadTTLIOChannelValue_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 4)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadTTLIOChannelValue:nrhs", "4 inputs are required.\n");
	if (nlhs != 2)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadTTLIOChannelValue:nlhs", "2 outputs are required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	portNbr = (BYTE)mxGetScalar(prhs[2]);
	channelNbr = (BYTE)mxGetScalar(prhs[3]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadTTLIOChannelValue:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((portNbr < 0) || (portNbr > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadTTLIOChannelValue:nlhs", "The portNbr input must be between 0 and 3.\n");
	if ((channelNbr < 0) || (channelNbr > 7))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexReadTTLIOChannelValue:nlhs", "The channelNbr input must be between 0 and 7.\n");

//##protect##"i_PCI1710_mexReadTTLIOChannelValue_Start"
//##protect##"i_PCI1710_mexReadTTLIOChannelValue_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_ReadTTLIOChannelValue(deviceHandle, moduleNumber, portNbr, channelNbr, value);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);
	plhs[1] = mxCreateNumericArray(0, NULL, mxUINT8_CLASS, mxREAL);
	mxSetData(plhs[1], value);  mxSetM(plhs[1], 1);  mxSetN(plhs[1], 1);

//##protect##"i_PCI1710_mexReadTTLIOChannelValue_End"
//##protect##"i_PCI1710_mexReadTTLIOChannelValue_End"
}
