//##protect##"FileHeader"
/** @file i_PCI1710_mexSetPortConfiguration.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 31.01.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  i_PCI1710_mexSetPortConfiguration MEX file 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "..\..\C\Include\PCI1710.h"
#include "mex.h"
#include "matrix.h"

/* i_PCI1710_mexSetPortConfiguration */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	/* Declaration of the local variables of the function */
	INT *returnValue = mxCalloc(1, sizeof(INT));
	HANDLE deviceHandle = 0;
	BYTE moduleNumber = 0;
	BYTE portAMode = 0;
	BYTE portBMode = 0;
//##protect##"i_PCI1710_mexSetPortConfiguration_VariablesDefinition"
//##protect##"i_PCI1710_mexSetPortConfiguration_VariablesDefinition"

	/* Check the number of input and output parameters */
	if (nrhs != 4)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexSetPortConfiguration:nrhs", "4 inputs are required.\n");
	if (nlhs != 1)
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexSetPortConfiguration:nlhs", "1 output is required.\n");

	/* Acquisition of the input(s) */
	deviceHandle = (HANDLE)(INT_PTR)mxGetScalar(prhs[0]);
	moduleNumber = (BYTE)mxGetScalar(prhs[1]);
	portAMode = (BYTE)mxGetScalar(prhs[2]);
	portBMode = (BYTE)mxGetScalar(prhs[3]);

	/* Check of the values of the input parameters */
	if ((moduleNumber < 0) || (moduleNumber > 3))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexSetPortConfiguration:nlhs", "The moduleNumber input must be between 0 and 3.\n");
	if ((portAMode < 0) || (portAMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexSetPortConfiguration:nlhs", "The portAMode input must be between 0 and 1.\n");
	if ((portBMode < 0) || (portBMode > 1))
		mexErrMsgIdAndTxt("MyToolbox:i_PCI1710_mexSetPortConfiguration:nlhs", "The portBMode input must be between 0 and 1.\n");

//##protect##"i_PCI1710_mexSetPortConfiguration_Start"
//##protect##"i_PCI1710_mexSetPortConfiguration_Start"

	/* Call of the C function */
	*returnValue = i_PCI1710_SetPortConfiguration(deviceHandle, moduleNumber, portAMode, portBMode);

	/* Creation of the output(s) */
	plhs[0] = mxCreateNumericArray(0, NULL, mxINT16_CLASS, mxREAL);
	mxSetData(plhs[0], returnValue);  mxSetM(plhs[0], 1);  mxSetN(plhs[0], 1);

//##protect##"i_PCI1710_mexSetPortConfiguration_End"
//##protect##"i_PCI1710_mexSetPortConfiguration_End"
}
