addpath('..\MATLAB\MEX');

% The following command clears the Command window
clc;
counter32Values = zeros(1, 1000);       % Read values 32-bit counter
firstCounter16Values = zeros(1, 1000);  % Read values 16-bit counter 0
secondCounter16Values = zeros(1, 1000); % Read values 16-bit counter 1
time = zeros(1, 1000);                  % Time base for displaying the values
i = 1;
timeClock = clock;

disp('%************************************************************%');
disp('%********     Sample for the incremental counter     ********%');
disp('%********      module of the the PCI1710 board       ********%');
disp('%************************************************************%');

% The following line displays an empty line
disp(' ');

% Acquisition of the inputs parameters
disp('Acquisition of the input parameters:');
index = input('Select the index of the board: ');
module = input('Select the module to use: ');
while ((module < 0) || (module > 3))
    disp('Wrong value for this parameter');
    module = input('Select the module to use: ');
end

disp(' ');
disp('Parameters for the i_PCI1710_InitCounter function: ');
range = input('Select the counter range (0: 32-bit counter, 16: 16-bit counter): ');
while ((range ~= 0) && (range ~= 16))
    disp('Wrong value for this parameter');
    range = input('Select the counter range (0: 32-bit counter, 16: 16-bit counter): ');
end
firstCounterMode = input('Select the first counter mode (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode): ');
while ((firstCounterMode ~= 0) && (firstCounterMode ~= 3) && (firstCounterMode ~= 15) && (firstCounterMode ~= 128))
    disp('Wrong value for this parameter');
    firstCounterMode = input('Select the first counter mode (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode): ');
end
firstCounterOption = input('Select the first counter option (if first counter mode is direct mode, 0: decrement, 96: increment; if first counter mode is quadruple, double or simple, 0: hysteresis off, 96: hysteresis on): ');
while ((firstCounterOption ~= 0) && (firstCounterOption ~= 96))
    disp('Wrong value for this parameter');
    firstCounterOption = input('Select the first counter option (if first counter mode is direct mode, 0: decrement, 96: increment; if first counter mode is quadruple, double or simple, 0: hysteresis off, 96: hysteresis on): ');
end
secondCounterMode = input('Select the second counter mode (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode): ');
while ((secondCounterMode ~= 0) && (secondCounterMode ~= 3) && (secondCounterMode ~= 15) && (secondCounterMode ~= 128))
    disp('Wrong value for this parameter');
    secondCounterMode = input('Select the second counter mode (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode): ');
end
secondCounterOption = input('Select the second counter option (if second counter mode is direct mode, 0: decrement, 96: increment; else if it is quadruple, double or simple, 0: hysteresis off, 96: hysteresis on): ');
while ((secondCounterOption ~= 0) && (secondCounterOption ~= 96))
    disp('Wrong value for this parameter');
    secondCounterOption = input('Select the first counter option (if first counter mode is direct mode, 0: decrement, 96: increment; if first counter mode is quadruple, double or simple, 0: hysteresis off, 96: hysteresis on): ');
end

disp(' ');

% We are obliged to call this function before opening the board
[returnError, nbBoards] = i_PCI1710_mexGetNumberOfBoards();
if (returnError ~= 0)
	disp('Error while getting the number of boards');
end

% Open the board
[returnError, handle] = i_PCI1710_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	disp('Error while opening the board');
end
% Call the init counter function
[returnError] = i_PCI1710_mexInitCounter(handle, module, range, firstCounterMode, firstCounterOption, secondCounterMode, secondCounterOption);
if (returnError ~= 0)
	disp('Error while initialiazing the counters');
end

% Initializes the value of the 32-bit counter
[returnError] = i_PCI1710_mexWrite32BitCounterValue(handle, module, 0);
if (returnError ~= 0)
    disp('Error while initializing the value');
    break;
end
% Initializes the value of the first 16-bit counter
[returnError] = i_PCI1710_mexWrite16BitCounterValue(handle, module, 0, 0);
if (returnError ~= 0)
    disp('Error while initializing the value');
    break;
end
% Initializes the value of the second 16-bit counter
[returnError] = i_PCI1710_mexWrite16BitCounterValue(handle, module, 0, 1);
if (returnError ~= 0)
    disp('Error while initializing the value');
    break;
end

disp('Acquisition in progress...');
disp('Please wait');

if (range == 0)
    for i = 1:1:1000        % With a value of 1000, the acquisition time lasts 15,6 sec
        t1 = clock;
        % Acquisition of the value of the counters
        [returnError, counter32Values(i)] = i_PCI1710_mexRead32BitCounterValue(handle, module);
        if (returnError ~= 0)
        	disp('Error while reading the value');
            break;
        end
        pause(0.001);        % Wait 1 ms
        t2 = clock;
        if (i > 1)
            time(i) = time(i-1) + etime(t2, t1);
        end
    end
    plot(time, counter32Values);
    xlabel('Time (in secondes)');
    ylabel('32-bit counter values');

elseif (range == 16)
    for i = 1:1:1000        % With a value of 1000, the acquisition time lasts 15,6 sec
        t1 = clock;
        % Acquisition of the value of the counter
        [returnError, firstCounter16Values(i)] = i_PCI1710_mexRead16BitCounterValue(handle, module, 0);
        if (returnError ~= 0)
        	disp('Error while reading the value');
            break;
        end
        [returnError, secondCounter16Values(i)] = i_PCI1710_mexRead16BitCounterValue(handle, module, 1);
        if (returnError ~= 0)
        	disp('Error while reading the value');
            break;
        end
        pause(0.001);        % Wait 1 us
        t2 = clock;
        if (i > 1)
            time(i) = time(i-1) + etime(t2, t1);
        end
    end
    subplot(1,2,1);
    plot(time, firstCounter16Values);
    xlabel('Time (in secondes)');
    ylabel('First 16-bit counter values');
    subplot(1,2,2);
    plot(time, secondCounter16Values);
    xlabel('Time (in secondes)');
    ylabel('Second 16-bit counter values');
end

disp(' ');
% Close the board
[returnError] = i_PCI1710_mexCloseBoard(handle);